pro plotprior,name,zarr=zarr,colordel=colordel,scanz=scanz
;
; need to run this in a new IDL session because we don't define all of
; the elements in the m2chisq common block

common m2chisq, startparam, info

if keyword_set(scanz) and n_elements(zarr) eq 0 then zarr = dindgen(6)/5.0d

if n_elements(zarr) eq 0 then zarr = [0d]
nz = n_elements(zarr)

if n_elements(colordel) eq 0 then colordel = 60.0/nz

info = { z: 0.0d }
startparam = [0.0d,0.0d,3.1d,0.0d,0.0d]

priorfn = 'prior_' + name
psfn = priorfn + '.ps'
ps = 1

ps_open,filename=psfn, /color

loadct,40
purp = 33
blue = 60
solid = 0

oldp = !p
oldx = !x
oldy = !y

th = 4

xcs = 1.25
ycs = 1.25

;!x.margin = [20,5]
!y.margin = [5,2]

!p.thick = th
!x.thick = th
!y.thick = th
!p.charthick = th

t0str = '(t!D0!N - t!Dinput!N) / (1+z)  [days]'
rvstr = 'R!DV!N'
delstr = '!7D!N!3'
avstr = 'A!DV!N  [mag]'

!p.multi = [0,2,2]

p0 = vec(-6d,6d,0.01d,nelems=np0)
pp0 = dblarr(np0)
for j=nz-1,0,-1 do begin
    info.z = zarr[j]
    for i=0L,np0-1 do pp0[i] = call_function(priorfn,[p0[i]*(info.z + 1.0d),startparam[1:4]])
    pp0 = exp(-(pp0-min(pp0))/2.0d)
    if j eq nz-1 then plot,p0,pp0,xtitle=t0str,ytitle='prior probability', $
      xcharsize=xcs,ycharsize=ycs,yr=[0,1.10],/yst,/xst,/nodata
    oplot,p0,pp0,color=purp+colordel*j,thick=th*2
endfor

del = vec(-0.8,2.1,0.01d,nelems=ndel)
pdel = dblarr(ndel)
for j=nz-1,0,-1 do begin
    info.z = zarr[j]
    for i=0L,ndel-1 do $
      pdel[i] = call_function(priorfn,[startparam[0],del[i],startparam[2:4]])
    pdel = exp(-(pdel-min(pdel))/2.0d)
    if j eq nz-1 then plot,del,pdel,xtitle=delstr,ytitle='prior probability' $
      ,xcharsize=xcs,ycharsize=ycs,yr=[0,1.10],/yst,/xst,/nodata
    oplot,del,pdel,color=purp+colordel*j,thick=th*2
endfor

av0 = vec(-2,4d,0.01d,nelems=nav0)
pav0 = dblarr(nav0)
tmpp = dblarr(nav0,nz)
xrng = [-0.2,0.2]   ; minimum range to plot
for j=nz-1,0,-1 do begin
    info.z = zarr[j]
    for i=0L,nav0-1 do pav0[i] = call_function(priorfn,[startparam[0:3],av0[i]])
    pav0 = exp(-(pav0-min(pav0))/2.0d)
    nonz = av0[where(pav0 gt 5d-3)]
    xrng[0] = min(nonz) < xrng[0]
    xrng[1] = max(nonz) > xrng[1]
    tmpp[0,j] = pav0
endfor

for j=nz-1,0,-1 do begin
    pav0 = tmpp[*,j]
    if j eq nz-1 then plot,av0,pav0,xtitle=avstr,ytitle='prior probability',xr=xrng $
      ,xcharsize=xcs,ycharsize=ycs,yr=[0,1.10],/yst,/xst,xminor=5,/nodata
    oplot,av0,pav0,color=purp+colordel*j,thick=th*2
endfor

for j=nz-1,0,-1 do begin
    info.z = zarr[j]
    rv = vec(0.5d,7.5d,0.01d,nelems=nrv)
    prv = dblarr(nrv)
    for i=0L,nrv-1 do $
      prv[i] = call_function(priorfn,[startparam[0:1],rv[i],startparam[3:4]])
    prv = exp(-(prv-min(prv))/2.0d)
    if j eq nz-1 then plot,rv,prv,xtitle=rvstr,ytitle='prior probability' $
      ,xcharsize=xcs,ycharsize=ycs,yr=[0,1.10],/yst,/xst,xminor=5,/nodata
    oplot,rv,prv,color=purp+colordel*j,thick=th*2
endfor

xyouts,5.4,0.8,name,align=0.5,charsize=xcs*1.3,charthick=th*1.2,color=purp

if nz gt 1 then begin
    for j=0,nz-1 do begin
        str = string(zarr[j],format='(f0.2)')
        if j eq 0 then str = 'z = ' + str
        xyouts,0.55 + 0.65*(j/double(nz-1) - 0.5),0.48,str,/normal, align=1.0 $
          ,charsize=xcs*(13.0/nz < 1.3),color=purp+colordel*j,charthick=th*1.2
    endfor
endif

ps_close,/noprint

!p = oldp
!x = oldx
!y = oldy

end

