function prior_adam, param

; returns -2*alog(prior(t0,del,rv,mu0,av0))
;   add this to chisq to get filtered chisq
;   chisq = chisq - 2 * alog(prior)
;         = chisq + getpriors(p0,del,rv,av0)

common m2chisq

av0 = param[4]
t0 = param[0]
p0 = (t0 - startparam[0])/(1.0d + info.z)
del = param[1]
rv = param[2]
mu0 = param[3]

out = 0.0d

; don't wander too far from zero phase because we don't have the right
; cmatrix for those dates. in the next iteration we will be closer to 
; being correct.
absp0max = 3.0d
absp0sig = 0.5d
if abs(p0) gt absp0max then out = out + ((abs(p0)-absp0max)/absp0sig)^2

; Adam puts pretty hard limits on delta
mindel = -0.40d
mindelsig = 0.001d
maxdel = 1.5d
maxdelsig = 0.001d

if del lt mindel then begin
    out = out + ((del-mindel)/mindelsig)^2
endif else if del gt maxdel then begin
    out = out + ((del-maxdel)/maxdelsig)^2
endif

; extinction prior(av0) approximates Adam's homebrew prior, which 
; is an exponential with scale length of 1.0 mag, convolved with
; a gaussian of 0.2 mag -- here's an analytic approximation that
; doesn't require we do a convolution/interpolation
peak = 0.25d
mf = 1.1d
sig = 0.23d
sav = av0-peak
if av0 gt peak then out += 2.0d * sav/mf + $
    2.0d * alog(((0.5-exp(-sav^4))/10.0 + 1.0d) + 0.05d*exp(-500*sav^2)) $
else out += 0.95*(sav/sig)^2 + 0.04d*(sav/sig)^4

; extinction law  prior is gaussian in 1/rv = rv1
; prior(rv1) \propto exp(-(rv1-rv1m)^2/2./rv1s^2)
;  these numbers correspond to <rv> = 3.1 and sd(rv) = 0.4
rv1m = (1.0d / 2.9639d)
rv1s = 0.03958d
rv1 = 1.0d / rv
out = out + ((rv1-rv1m)/rv1s)^2

return, out

end
