function ewindow,x,half,cut
;
;  helper function written by pg, 2006-Sep-17
;
;  window function uses the erf to
;  make a window function. Starting at x=0 with
;  the value y0. half is the x-position of the
;  half max value and cut is the slope of the window
;  cutoff
;
return, (erf(cut*(half-x))+1.0d)/2.0d

end

function prior_glosz, param

; returns -2*alog(prior(t0,del,rv,mu0,av0))
;   add this to chisq to get filtered chisq
;   chisq = chisq - 2 * alog(prior)
;         = chisq + getpriors(p0,del,rv,av0)
; This is a modification of the "glos" prior
;  It cuts off the prior as a function of z
;  based on simulations of the ESSENCE sensitivity

; made prettier by MWV, originally by PMG 2006-Sep-17

common m2chisq

av0 = param[4]
; check extinction right away to save some time
if av0 lt 0.0d then return,1d9

t0 = param[0]
p0 = (t0 - startparam[0])/(1.0d + info.z)
del = param[1]
rv = param[2]
mu0 = param[3]

out = 0.0d

; don't wander too far from zero phase because we don't have the right
; cmatrix for those dates. in the next iteration we will be closer to 
; being correct.
absp0max = 3.0d
absp0sig = 0.5d
if abs(p0) gt absp0max then out = out + ((abs(p0)-absp0max)/absp0sig)^2

; don't go out of bounds on delta where we didn't have much training info
;   these numbers were optimized during the training, so don't change them
mindel = -0.30d
mindelsig = 0.10d
maxdel = 1.6d
maxdelsig = 0.10d

zwin=[0.0, 0.1, 0.35, 0.40, 0.45, 0.50, 0.55, 0.60, 0.65,  0.70,  0.75]
half=[2.3, 1.9, 0.93, 0.75, 0.60, 0.43, 0.29, 0.17, 0.05, -0.09, -0.25]
cut =[2.4, 2.4, 2.4 , 2.4 , 2.6 , 2.6 , 2.7 , 2.8 , 3.0 ,  3.3 ,  3.3 ]
half0=interpol(half,zwin,info.z)
cut0 =interpol(cut ,zwin,info.z)
pdel=ewindow(del,half0,cut0) > 1d-100 ; 

if del lt mindel then begin
;    out = out + ((del-mindel)/mindelsig)^2
    out = out + ((del-mindel)/mindelsig)^2+(-2.0d0*alog(pdel))
endif else if del gt maxdel then begin
;    out = out + ((del-maxdel)/maxdelsig)^2
    out = out + ((del-maxdel)/maxdelsig)^2+(-2.0d0*alog(pdel))
endif
if (del ge mindel) and (del le maxdel) then out=out+(-2.0d0*alog(pdel))

; extinction prior(av0) exponential with scale length = 0.4 mag 
;  plus a "delta" function (really a one-sided Gaussian with sigma = 0.1 mag)
;  with the delta function getting 1/2 weight of exponential
;
; this attempts to mimic results from calculations like those of
;   Hatano, Branch, & Deaton 1998, ApJ, 502, 177
;   Commins 2004, NewAR, 48, 567
;
zwin=[0.0, 0.1, 0.35, 0.40, 0.45, 0.50, 0.55, 0.60, 0.65, 0.70, 0.75]
half=[3.0, 2.5, 1.35, 1.05, 0.88, 0.67, 0.48, 0.33, 0.20, 0.10, 0.05]
cut =[1.0, 1.5, 2.2 , 2.5 , 2.6 , 2.8 , 3.5 , 4.0 , 5.0 , 6.0 , 7.5 ]
half0=interpol(half,zwin,info.z)
cut0=interpol(cut,zwin,info.z)
penal=ewindow(av0,half0,cut0) > 1d-100
;
avtau = 0.4d
avsdelt = 0.1d
sqrt2pi = sqrt(2.0d*!dpi)
wtexp = 1.0d
wtdelt = 0.5d
normpeak = wtdelt/sqrt2pi/avsdelt*2.0d + wtexp/avtau 
pav = wtdelt * exp(-av0^2/2.0d/avsdelt^2)/sqrt2pi/avsdelt*2.0d +  $
      wtexp * exp(-av0/avtau)/avtau
pav /= normpeak
pav=pav*penal
out = out + (-2.0d * alog(pav))
;print,'Prior ',av0,penal,pav,-2.0d * alog(pav)

; extinction law  prior is gaussian in 1/rv = rv1
; prior(rv1) \propto exp(-(rv1-rv1m)^2/2./rv1s^2)
;  these numbers correspond to <rv> = 3.1 and sd(rv) = 0.4
rv1m = (1.0d / 2.9639d)
rv1s = 0.03958d
rv1 = 1.0d / rv
out = out + ((rv1-rv1m)/rv1s)^2

return, out

end

