function prior_tonry, param

; returns -2*alog(prior(t0,del,rv,mu0,av0))
;   add this to chisq to get filtered chisq
;   chisq = chisq - 2 * alog(prior)
;         = chisq + getpriors(p0,del,rv,av0)

common m2chisq

av0 = param[4]
t0 = param[0]
p0 = (t0 - startparam[0])/(1.0d + info.z)
del = param[1]
rv = param[2]
mu0 = param[3]

out = 0.0d

; don't wander too far from zero phase because we don't have the right
; cmatrix for those dates. in the next iteration we will be closer to 
; being correct.
absp0max = 3.0d
absp0sig = 0.5d
if abs(p0) gt absp0max then out = out + ((abs(p0)-absp0max)/absp0sig)^2

; don't go out of bounds on delta where we didn't have much training info
;   these numbers were optimized during the training, so don't change them
mindel = -0.30d
mindelsig = 0.10d
maxdel = 1.6d
maxdelsig = 0.10d

if del lt mindel then begin
    out = out + ((del-mindel)/mindelsig)^2
endif else if del gt maxdel then begin
    out = out + ((del-maxdel)/maxdelsig)^2
endif

; extinction prior, Gaussian with sigma=1.0 mag on the positive side
;    sigma = 0.2 mag on the negative side, and 50% of those weights 
;    in a "delta" function (really a Gaussian with sigma = 0.1 mag)
; this is an attempt to approximate the prior of Tonry et al. 2003
avsigma = 1.0d
avneg = 0.2d
avsdelt = 0.1d
sqrt2pi = sqrt(2.0d*!dpi)
norm1 = sqrt2pi*(avneg+avsigma)/2.0d
pav = 0.25d * ( exp(-av0^2/2.0d/avsdelt^2)/sqrt2pi/avsdelt*norm1/2.0d + $
                ( (av0 lt 0d) ? exp(-av0^2/2.0d/avneg^2) $
                              : exp(-av0^2/2.0d/avsigma^2) ) )
out = out + (-2.0d * alog(pav))


; extinction law  prior is gaussian in 1/rv = rv1
; prior(rv1) \propto exp(-(rv1-rv1m)^2/2./rv1s^2)
;  these numbers correspond to <rv> = 3.1 and sd(rv) = 0.4
rv1m = (1.0d / 2.9639d)
rv1s = 0.03958d
rv1 = 1.0d / rv
out = out + ((rv1-rv1m)/rv1s)^2

return, out

end
