FUNCTION Cmp_Avg, x, $
                  nrej = nrej, $
                  xrej = xrej, rms = r, mRMS = mRMS, $
                  idx = idx, cnt = nx, rRMS = rRMS
;
;+
; Name:
;             Cmp_Avg
;
; Purpose:
;           computes average of argument: Cmp_Avg(x) = total(x)/n_elements(x) 
;
; Calling Sequence:
;          avg = Cmp_Avg(x)
;
; Keywords:
;
;   nrej: if set, will perform an RMS rejection NREJ times
;   xrej: rejection factor, default 3.0
;   rms:  return the RMS of the pts included
;   mRMS: computes the RMS of the mean (extra sqrt(cnt))
;   idx:  indices of pts included
;   cnt:  no of points included
;   rRMS: divide by N rather than N-1
;-
;  --------------- -
;= CMP_AVG         - computes average of argument
; ---------------------------------------------------------------------------
;
on_error, 1
;
IF keyword_set(nrej) THEN BEGIN
  IF keyword_set(rRMS) THEN sub = 0 else sub = 1
  IF NOT keyword_set(xrej) THEN xrej = 3.0
  nx = n_elements(x)
  idx = indgen(nx)
  FOR irej = 1, nrej DO BEGIN
    a = total(x[idx])/nx
    r = sqrt(total((x[idx]-a)^2)/(nx-sub))
    idx = where(abs(x-a) LE xrej*r,  nx)
  ENDFOR
  a = total(x[idx])/nx
  IF keyword_set(mRMS) THEN $
    r = sqrt(total((x[idx]-a)^2))/(nx-sub) $
  ELSE $
    r = sqrt(total((x[idx]-a)^2)/(nx-sub))
ENDIF ELSE BEGIN
  a = total(x)/n_elements(x)
ENDELSE
;
return, a
END
