pro convertprior, sn, iter, newprior, fitdir=fitdir

;
; routine to very quickly convert a grid from one prior to another
;
;    USE THIS CAREFULLY, just to get an indication of how
;    things might change with the new prior, as there is
;    NO GUARANTEE that these results will match a real fit
;    using the new prior (because the grid points may all
;    be away from the high probability regions in the new
;    prior).
;    
;    IN ADDITION, regions of parameter space that are 
;    disallowed by the original prior will not be correct
;    in the new prior (because we didn't bother to calculate
;    the true chisq in disallowed regions)
;
;    SO AVOID THIS ROUTINE if you can just re-fit properly
;    with the new prior
;

common m2setup, c,s,n,sall,rfcname
common m2grid, grid,t0,del,rv,mu0,av0,nt0,ndel,nrv,nmu0,nav0 $
  ,dt0,ddel,drv,dmu0,dav0,csgrid,finalnpoints
common m2chisq, fixarr,fixval,vectors,redden,info,obspb,restpb,data,orpbind $
  ,kctables,gxtables,cinv,npts,startparam,nuniqf

m2dir = getenv('MLCS2K2_BASEDIR') + '/'

if not keyword_set(fitdir) then fitdir = m2dir + 'fit/out/' + sn + '/' $
else if strmid(fitdir,0,1,/reverse) ne '/' then fitdir += '/'

istr = string(iter,format='(i02)')
fitfn = sn + '.iter' + istr + '.grid.sav'

files = file_search(fitdir+sn+'.iter' + istr + 'x??' + '.fit.out',count=nfiles)

if nfiles eq 0 then nstr = '00' $
else begin
    files = files[sort(files)]
    lastfile = file_basename(files[nfiles-1])
    pos = strpos(lastfile,'.fit.out')-2
    nstr = string(fix(strmid(lastfile,pos,2))+1,format='(i02)')
endelse
    
newbase = sn+'.iter'+istr+'x'+nstr 

restore,fitdir+fitfn

oldprior = info.priorpro

message,'attemping to convert prior from ' + oldprior + ' to ' + newprior,/info
print,'old mean parameters: ' + string(outp,format='(f12.3,4f9.3)')

; stick prior directory at the front of the path:
oldpath = !path
priordir = m2dir + 'fit/priors'
!path = priordir + path_sep(/search_path) + !path

now = dblarr(5)

oldprisq = csgrid-csgrid
newprisq = oldprisq

for it0=0L,nt0-1 do begin
    now[0] = t0[it0]
    for idel=0L,ndel-1 do begin
        now[1] = del[idel]
        for irv=0L,nrv-1 do begin
            now[2] = rv[irv]
            for imu0=0L,nmu0-1 do begin
                now[3] = mu0[imu0]
                for iav0=0L,nav0-1 do begin
                    now[4] = av0[iav0]

                    nowparam = fixparam(now,fixarr,fixval)
                    oldprisq[it0,idel,irv,imu0,iav0] = call_function('prior_'+oldprior,nowparam)
                    newprisq[it0,idel,irv,imu0,iav0] = call_function('prior_'+newprior,nowparam)

                endfor
            endfor
        endfor
    endfor
endfor

bad = where(oldprisq gt 1d6 and newprisq lt 1d6,nbad)
if nbad gt 0 then begin
    oldprisq[bad] = 0d
    message,'warning! '+string(nbad,format='(i0)') + ' of ' + $
      string(nn,format='(i0)') + ' grid points incorrectly converted',/info
endif

csgrid += (newprisq - oldprisq)

info.priorpro = newprior

!path = oldpath

mincs = min(csgrid,minind)
ind = array_indices(csgrid,minind)
csmin = [t0[ind[0]],del[ind[1]],rv[ind[2]],mu0[ind[3]],av0[ind[4]]]

test = getchisq(csmin,prisq=prisq)
if mincs gt 1d-3 then $
  if (abs(test-mincs)/mincs) gt 1d-5 then message,'huh? something changed!'

;; Transform from chisq to probability space
pgrid = exp((mincs-csgrid)/2.0d)
pgrid = pgrid/total(pgrid*dt0*ddel*drv*dmu0*dav0)

;; Calculate 1D marginalized probabilities for each fit parameter
pt0 = dblarr(nt0)
for z=0,nt0-1 do pt0[z] = total(pgrid[z,*,*,*,*]*ddel*drv*dmu0*dav0)

pdel = dblarr(ndel)
for z=0,ndel-1 do pdel[z] = total(pgrid[*,z,*,*,*]*dt0*drv*dmu0*dav0)

prv = dblarr(nrv)
for z=0,nrv-1 do prv[z] = total(pgrid[*,*,z,*,*]*dt0*ddel*dmu0*dav0)

pmu0 = dblarr(nmu0)
for z=0,nmu0-1 do pmu0[z] = total(pgrid[*,*,*,z,*]*dt0*ddel*drv*dav0)

pav0 = dblarr(nav0)
for z=0,nav0-1 do pav0[z] = total(pgrid[*,*,*,*,z]*dt0*ddel*drv*dmu0)

;; Calculate means for each fit parameter
mu0mean = total(mu0*pmu0*dmu0)
mu0sd = sqrt((total(mu0*mu0*pmu0*dmu0) - mu0mean*mu0mean) > 0.0d)

m0mean = mu0mean + getzeropoint(info.vecname)
m0sd = mu0sd

av0mean = total(av0*pav0*dav0)
av0sd = sqrt((total(av0*av0*pav0*dav0) - av0mean*av0mean) > 0.0d)

delmean = total(del*pdel*ddel)
delsd = sqrt((total(del*del*pdel*ddel) - delmean*delmean) > 0.0d)

t0mean = total(t0*pt0*dt0)
t0sd = sqrt((total(t0*t0*pt0*dt0) - t0mean*t0mean) > 0.0d)

rvmean = total(rv*prv*drv)
rvsd = sqrt((total(rv*rv*prv*drv) - rvmean*rvmean) > 0.0d)

outp = [t0mean, delmean, rvmean, mu0mean, av0mean]
outperr = [t0sd, delsd, rvsd, mu0sd, av0sd]

print,'new mean parameters: ' + string(outp,format='(f12.3,4f9.3)')

csp = getchisq(outp,resid=cspresid,prisq=cspprisq,obslc=cspolc,restphase=rphase, $
              gxout=cspgx,kcout=cspkc,kcsig=cspkcsig,gxsig=cspgxsig)

model = { obslc: cspolc, $
          gx: cspgx, gxsig: sqrt(cspgxsig^2+(0.16d*cspgx)^2), $
          kc: cspkc, kcsig: cspkcsig, $
          c: c, s: s, n: n, $
          phase: rphase, $
          mingoodate: vectors.mingoodate, maxgoodate: vectors.maxgoodate }

out = { sn: sn, $
        info: info, $
        param: outp, $
        err: outperr, $
        mincs: mincs, $
        csminparam: csmin, $
        prisq: prisq, $
        ndof: ndof, $
        startparam: startparam, $
        obspb: obspb, $
        restpb: restpb, $
        data: data, $
        model: model, $
        resid: cspresid }

gridfn = fitdir+newbase+'.grid.sav'
save,file=gridfn,/compress



printfitout,sn,out,iter,outdir=fitdir,addobspb=addobspb,/grid,baseappend='x'+nstr

obsframefn = fitdir+newbase+'.obsframe.dat'
psfn = fitdir+newbase+'.grid.ps'
plotfit,sn,out,obsframefn,gridfn=gridfn,psfn=psfn

end
