pro datamodel, fitout, file, hisnrfn=hisnrfn

;; Writes out data file used with corresponding best-fit model points
;;
;; Inputs:
;;
;;   fitout      : result from amoebafit or gridfit
;;   file        : filename for a output file with the generated lightcurve.  
;;

openw,lun,file,/get_lun

begstr = '  '
for q=0,22 do begstr = begstr + '#'
now = systime()
titlestr = '#######  MLCS2k2 datamodel.pro  ' + now + begstr

printf,lun,titlestr
printf,lun,'#'
printf,lun,'# output file: ' + file
printf,lun,'#'
printf,lun,'# input parameters: '
printf,lun,'#   time of Bmax                       t0 = '+strtrim(fitout.param[0],2)
printf,lun,'#   distance modulus [H0=65]         mu65 = '+strtrim(fitout.param[3],2)
printf,lun,'#   delta                             del = '+strtrim(fitout.param[1],2)
printf,lun,'#   V-band host extinction at tmax    av0 = '+strtrim(fitout.param[4],2)
printf,lun,'#   extinction law                     rv = '+strtrim(fitout.param[2],2)
printf,lun,'#   redshift                            z = '+strtrim(fitout.info.z,2)
printf,lun,'#   MW SFD extinction              galebv = '+strtrim(fitout.info.ebvsfd,2)
printf,lun,'#'
printf,lun,'#   spectral library used        specsamp = '+strtrim(fitout.info.specsamp,2)
printf,lun,'#   vectors used                  vecname = '+strtrim(fitout.info.vecname,2)
printf,lun,'#'
printf,lun,'#              light curve data                   model                                                                 SNR'
printf,lun,'# obs-passband     HJD      mag    err     phase   mag  sqrt(C)  resid   kcorr  +/-   galext  +/-   sqrt(S) rest-pb  obs   model warnings'

ndata = n_elements(fitout.data)

snrstatus = bytarr(ndata)
statstr = ['   ok   ','  late  ',' early  ','OBSSNR! ','MODSNR! ','OUTLIER!']
defaultssnr, mingoodsnr, outliersnr

for i=0l,ndata-1 do begin

    obsmodsnr,fitout.data[i].mag,fitout.data[i].err,fitout.model.obslc[i],obssnr,modsnr

    if obssnr lt mingoodsnr then snrstatus[i] = 3 $
    else if modsnr lt mingoodsnr then snrstatus[i] = 4 $
    else if abs(fitout.resid[i]/sqrt(fitout.model.c[i,i])) gt outliersnr then snrstatus[i] = 5 $
    else if fitout.model.phase[i] gt fitout.model.maxgoodate then snrstatus[i] = 1 $
    else if fitout.model.phase[i] lt fitout.model.mingoodate then snrstatus[i] = 2 $
    else snrstatus[i] = 0

    s = strjust(fitout.data[i].obspbname,15,/center) + $
      string(fitout.data[i].jd,format='(f10.3)') + $
      string(fitout.data[i].mag,format='(f8.3)') + $
      string(fitout.data[i].err,format='(f6.3)') + $
      string(fitout.model.phase[i],format='(f9.3)') + $
      string(fitout.model.obslc[i],format='(f8.3)') + $
      string(sqrt(fitout.model.c[i,i]),format='(f6.3)') + $
      string(fitout.resid[i],format='(f8.3)') + $
      string(fitout.model.kc[i],format='(f8.3)') + $
      string(fitout.model.kcsig[i],format='(f6.3)') + $
      string(fitout.model.gx[i],format='(f8.3)') + $
      string(fitout.model.gxsig[i],format='(f6.3)') + $
      string(sqrt(fitout.model.s[i,i]),format='(f8.3)') + $
      strjust(fitout.data[i].restpbname,6,/right) + $
      string(obssnr,format='(f9.1)') + $
      string(modsnr,format='(f6.1)') + $
      '  ' + statstr[snrstatus[i]]

    printf,lun,s

endfor

close,lun
free_lun,lun

if n_elements(hisnrfn) eq 1 then begin

    openw,lun,hisnrfn,/get_lun

    printf,lun,titlestr
    printf,lun,'#'
    printf,lun,'# output file: ' + hisnrfn
    printf,lun,'#'

    for i=0l,ndata-1 do begin
        
        s = strjust(fitout.data[i].obspbname,15,/center) + $
          string(fitout.data[i].jd,format='(f10.3)') + $
          string(fitout.data[i].mag,format='(f8.3)') + $
          string(fitout.data[i].err,format='(f6.3)')

        if snrstatus[i] le 2 then s = '  ' + s $
        else s = '# ' + s + '   ' + statstr[snrstatus[i]]

        printf,lun,s

    endfor

    close,lun
    free_lun,lun

endif

end
