function defaultgrid, param, err

;; 2006/07/10 - Some additional commentary by Michael Wood-Vasey
;;   Specifies algorithm for refinement between grid iterations and
;;    number of grid points to use.  This directly affects how long it
;;    takes for the fitting to complete since the time scales by the
;;    total number of grid points.  There is no explicit convergence
;;    criterion used here.  The scalings are adhoc but try to roughly
;;    cover 3-4 times the sigma of the previous iteration.  The range
;;    covered is specified by +-npoints*steps/2 around the previous fit value.
;;
;;   npoints should be odd numbers so that we hit the central value
;;
;;   There's a special case for the first fit based on the amoeba fit
;;    when we don't have a pre-existing grid to give us error estimates.
;;
;;   Returns an 'sn_grid' structure with the number of points, 
;;    central  values and step size for each parameter in the grid.

defaultsrvfit, minav, rvminav

centers = param

if max(err) lt 1d-4 then begin
    ; we are doing the grid for the first time

    ;;   t0, del, rv, mu, av0
    npoints = [7L,   11,    5,    11,    11]   ;; should be odd numbers
      steps = [1.0d, 0.05d, 0.4d, 0.1d, 0.1d]
endif else begin
    ; we are updating the grid

    ;;   t0, del, rv, mu, av0
    npoints = [9l,13,7,13,13]
   
    message, 'passed-in errors: ' + string(err,format='(5f8.3)'), /info
    steps = [ err[0]/1.3d > 0.12d, $
              err[1]/1.5d > 0.01d, $
              err[2]/1.2d > 0.12d, $
              err[3]/1.5d > 0.02d, $
              err[4]/1.5d > 0.005d ]

endelse

if param[4] le minav then begin
    ; we will fix R_V
    npoints[2] = 1
    centers[2] = rvminav
    steps[2] = 1.0d
endif

out = { sn_grid, $
        npoints: npoints, $
        centers: centers, $
          steps: steps }

return,out

end
