function getkc,ph,rfcol,rfcolname,rf,obsf,z $
              ,sample=sample,rfcolset=rfcolset $
              ,kc_lookup=kc_lookup $
              ,sigma=sigma
;
; getkc.pro -- computes the K-correction
;
; Created 2005-Nov-09
; Version 2006-Oct-24
;               
; INPUTS
;        ph: rest-frame phases (scalar or array)
;     rfcol: rest-frame colors matching phases (scalar or array)
; rfcolname: rest-frame color name (string: 
;                                  'U-B', 'B-V', 'V-R', 'R-I', or 'V-I')
;        rf: rest-frame passband (string or passband structure)
;      obsf: observer-frame passband (string or passband structure)
;         z: redshift (scalar)
;     
; RETURN VALUE
;  computed k-corrections (magnitudes, same number of elements as ph)
;
; OPTIONAL INPUTS
;    sample: spectral sample to use (string, default: 'normal')
;  rfcolset: rest-frame color set (string, default: 'Bessell')
;
; kc_lookup: pre-loaded K-correction lookup table structure;
;            if you supply this (from kc_loadfile), the inputs for
;            rfcolname, rf, obsf, z, sample, and rfcolset are ignored
;
; OPTIONAL OUTPUTS
;     sigma: K-correction uncertainty (same number of elements as ph)
;
;        **NOTE** this is only an estimate of the uncertainty from the
;        spectral calculation. It does not include the uncertainty because
;        your input colors may be uncertain. For the synthetic spectral
;        samples (like the nugent ones), the estimate doesn't work because
;        it relies on the variation among individual spectra. For those
;        samples you will probably need to augment the uncertainty to
;        something reasonable.
;        

nkcl = n_elements(kc_lookup)
if nkcl gt 1 then message,'multiple kcorr lookup tables not supported'
if nkcl eq 0 then begin
    ; we need to look at the other arguments
    if n_elements(sample) eq 0 then sample = 'normal'
    if n_elements(rfcolset) eq 0 then rfcolset = 'Bessell'
    if n_elements(z) ne 1 then $
      message,'redshift must be a scalar'
    if n_elements(rfcolname) ne 1 then $
      message,'multiple rest-frame colors not supported yet'
    loadtable = 1
endif else begin
    loadtable = 0
endelse

n = n_elements(ph)
if n_elements(rfcol) ne n then $
  message,'phases and rest-frame color array have different sizes'

if loadtable then begin
    ; first we determine the name of the lookup table
    fn = kc_getfilename(z,rfcolname,rf,obsf,sample,rfcolset)
    ; load the lookup table
    kctable = kc_loadfile(fn)
endif else begin
    kctable = kc_lookup
endelse

; calculate the k-corrections and errors via interpolation
kc_lookup,kctable,ph,rfcol,outkc,sigma

; return them
return,outkc

; calculate filter match #?
; calculate whether this is a good idea?
;    i.e. rest-frame color should constrain rest-frame filter

end
