function getlevels,p,dp,area,maxdiff=maxdiff,nowarn=nowarn,increase=increase $
                  ,outarea=outarea                         ;,verbose=verbose

;; 2006/07/10 - Some additional commentary by Michael Wood-Vasey
;;     Get the appropriate levels for the purposes of contour plotting
;;      of a probability distribution surface

;verbose=keyword_set(verbose)

if not keyword_set(maxdiff) then maxdiff = 5d-4

vdiff = maxdiff/10.0d/double(n_elements(p))

if not keyword_set(nowarn) then begin
    atot = total(p*dp)
    if abs(atot - 1.0d) ge maxdiff/10.0d then $
      message,'warning, total area is not unity: ' + string(atot),/info

endif

n = n_elements(area)
if n eq 1 then area = [area]

out = dblarr(n)
outarea = dblarr(n) 


for i=0,n-1 do begin
    minlev = min(p)
    maxlev = max(p)

    a = -1.0d
;    reps = 0

    repeat begin

        outlev = (minlev+maxlev)/2.0d
        q = where(p ge outlev)
        a = total(p[q]*dp)
;        reps++
        done = (abs(a-area[i]) lt maxdiff) or (abs(maxlev-minlev) lt vdiff)

;       if verbose then print,reps,minlev,maxlev,outlev,area[i],a
            
        if not done then begin
            if a gt area[i] then minlev = outlev else maxlev = outlev
        endif

    endrep until done

    out[i] = outlev
    outarea[i] = a

endfor

; IDL's contour procedure requires these levels to be increasing
;   in some cases the contours will identical for poorly resolved data
;   here we make sure that the levels increase
if keyword_set(increase) and n gt 1 then begin    

    diff = out[1:n-1] - out[0:n-2]
    if min(diff) lt (-1.0d * vdiff) then begin
        message,' levels are decreasing!'
    endif else begin
        diff = diff > vdiff
        for i=0,n-2 do out[i+1] = out[i]+diff[i]
    endelse

endif

;if verbose then begin
;    print,out
;    print,outarea
;    print,reps
;endif 



return,out

end
