function getobslc, param, vectors, redden, info, obspb, restpb, data, orpbind $
                   ,kctables=kctables,gxtables=gxtables, restphase=restphase $
                   ,rlc=rlc, kcout=kcout, kcsig=kcsig, gxout=gxout, gxsig=gxsig

;; 2006/07/10 - Some additional commentary by Michael Wood-Vasey
;;     Get the the observed lightcurve for a given set of MLCS2k2 model parameters
;;     and for the specified dates.
;;
;;     This function is similar to 'fullobslc.pro', but the latter
;;     returns a full lightcurve with daily sampling and can
;;     optionally generate an output file.
;;
;;     This version is streamlined for internal use in the code.

; kctables and gxtables are required!
;
; TODO: change getkc and getgx calls to check if kctables are defined
; first, but probably that would make it -really- slow
;
npts = n_elements(data)
nuniqf = n_elements(obspb)

if npts gt 0 then begin

    restphase = (data.jd - param[0])/(1.0d + info.z)

    rlc = getrestlc(param,vectors,redden,data.restpbind,restphase,colors=colors)

    kcout = dblarr(npts)
    kcsig = kcout
    gxout = kcout
    gxsig = kcout
    for i=0,nuniqf-1 do begin

        qq = where(orpbind eq i,nqq)

        if nqq gt 0 then begin

            kc_lookup, kctables, restphase[qq], colors[qq], nowkc, nowks, index=i
            kcout[qq] = nowkc
            kcsig[qq] = nowks  

            gx_lookup, gxtables, restphase[qq], info.ebvsfd, colors[qq], nowgx, nowgs, index=i
            gxout[qq] = nowgx
            gxsig[qq] = nowgs

        endif
  
    endfor

    olc = rlc + kcout + gxout

endif else begin

    message,'use fullobslc.pro to get complete obsframe light curves'

endelse

return,olc

end
