function getpb, name, pbdir=dir, natspline=natspline, fullhdr=hdr

;
; getpb.pro -- returns a passband (as a structure)
;
; Created 2005-Oct-30
; Version 2005-Nov-12
;               
; INPUTS
;     name: name of the passband
;              there are default translations for U B V R I J H K
;              in translatepb.pro
;
; OPTIONAL INPUTS
;    pbdir: directory containing the passbands
;           by default this is $MLCS2K2_BASEDIR/aux/passbands/
;           we also check the filename directly (so you could specify
;           a whole path-specified file in name, without the .fits) 
;
; natspline: allow first derivative at passband edge to be nonzero
;            (set this only if there's a sharp break at the edge)
;
; OPTIONAL OUTPUTS
;  fullhdr: the full header of the passband fits file
;

if n_elements(dir) eq 0 then $
  dir = getenv('MLCS2K2_BASEDIR') + '/aux/passbands/'

natspline = keyword_set(natspline)

; do some default translations
pn = translatepb(name)

fn = dir + pn + '.fits'
if not file_test(fn) then begin
    if file_test(pn + '.fits') then fn = pn + '.fits' $
      else message,'file not found: ' + fn
endif

pb = mrdfits(fn,1,hdr,/silent)

splin = (natspline) ? spl_init(pb.wavelength,pb.response) $
                    : spl_init(pb.wavelength,pb.response,yp0=0.0d,ypn_1=0.0d)


out = { name:strtrim(sxpar(hdr,'PBNAME'),2), $
        wavelength:pb.wavelength, $
        response:pb.response, $
        zp:double(sxpar(hdr,'ZEROPT')), $
        respunit: strtrim(sxpar(hdr,'RESPUNIT'),2), $
        splinit: splin }

return,out

end
