function getrestlc, param, vectors, redden, restpbind, restph, colors=colors

;; 2006/07/10 - Some additional commentary by Michael Wood-Vasey
;;     Get the rest-frame lightcurve for the given model parameters and phases.


;t0guess = param[0]    ; we don't need this, restph was already calculated
delguess = param[1]
rvguess = param[2]
mu0guess = param[3]
av0guess = param[4]

npts = n_elements(restph)

if n_elements(restpbind) ne npts then $
  message,' rest-frame passbands and phases array mismatch'

if npts gt 0 then begin
    ; here we calculate the answers interpolated on the restph array
    ; this is not as straightforward, because to get the colors
    ; we have to do additional calculations. for example, the data
    ; might ask for U at +3 days, but that means we have to
    ; calculate both U and B at +3 days to get the color, even
    ; though B at +3 days is not necessarily in the data.

    ; to do this we just calculate all the filters at all of
    ; the restphases -- this is overkill, but since we can do
    ; a lot of array operations it shouldn't be too much slower.

    tmpout = dblarr(npts,vectors.nfilters)
    tmpcol = tmpout

    locdate = interpol(dindgen(vectors.ndate),vectors.date,restph)
    locphase = interpol(dindgen(redden.nphase),redden.phase,restph)

    ; calculate the magnitudes on the restph array
    for i=0,vectors.nfilters-1 do begin
        tmpout[0,i] = reform(interpolate(vectors.mt[i,*],locdate) + $
          interpolate(vectors.pt[i,*],locdate)*delguess + $
          interpolate(vectors.qt[i,*],locdate)*delguess^2 + $
          mu0guess + $
          (redden.ccmax[i] + redden.ccmbx[i]/rvguess) * $
          interpolate(redden.zeta[i,*],locphase)*av0guess)
    endfor

    ; calculate the colors
    for i=0,vectors.nfilters-1 do begin
        tmpcol[0,i] = tmpout[*,vectors.fcol1[i]] - tmpout[*,vectors.fcol2[i]]
    endfor

    ; okay now figure out which ones we actually need
    ii = indgen(npts)
    out = tmpout[ii,restpbind]
    colors = tmpcol[ii,restpbind]

endif else begin
    ; here we weren't supplied rest-frame info so we just return
    ; the data on the "date" array

    out = dblarr(vectors.ndate,vectors.nfilters)
    colors = out

    ; calculate the magnitudes on the date array
    for i=0,vectors.nfilters-1 do begin

        out[0,i] = reform(vectors.mt[i,*] + $
          vectors.pt[i,*]*delguess + $
          vectors.qt[i,*]*delguess^2 + $
          mu0guess + $
          (redden.ccmax[i] + redden.ccmbx[i]/rvguess) * $
          interpol(redden.zeta[i,*],redden.phase,vectors.date) * av0guess)

    endfor

    ; calculate the colors
    for i=0,vectors.nfilters-1 do begin
        colors[0,i] = out[*,vectors.fcol1[i]] - out[*,vectors.fcol2[i]]
    endfor
    
endelse

return,out

end

