function getsmatrix, vecname, restpbs, phases, sall, restore=restore, fn=fn

; get the S matrix for an array of filters & phases
;
; there are two calling options:
;
; 1. s = getsmatrix(vecname,restpbs,phases,/restore)
;      this restores the cmatrix save file from disk
;
; 2. s = getsmatrix(vecname,restpbs,phases,sall)
;      this uses the sall array you pass
; 
; it's purely to avoid reading in the large .sav file every time
;
; note if you mix the two calling options, your sall will get 
; overwritten by the restored version. that might be what you want.
;

n = n_elements(restpbs)
if n_elements(phases) ne n then message,'array size mismatch restpbs/phases'

if keyword_set(restore) then begin
    if n_elements(fn) eq 0 then $
      fn = getenv('MLCS2K2_BASEDIR') + '/train/'+vecname+'.smatrix.sav'
    restore,fn
endif

fils = lonarr(n)
for i=0,n-1 do begin
    match = where(filters eq restpbs[i],nmatch)
    if nmatch ne 1 then $
      message,' unknown rest frame passband: ' + restpbs[i]
    fils[i] = match[0]
endfor

foff = fils*ndate

loc = ((interpol(dindgen(ndate),date,phases) > 0d) < (ndate - 1d))

mindate = min(date)
maxdate = max(date)
goodph = (phases le maxdate and phases ge mindate) 

out = dblarr(n,n)

; do the diagonal elements (we only want to interpolate along the
;    diagonal for these, so we do it separately)

sdiag = diag_matrix(sall)
outdiag = dblarr(n)

floc = loc + foff

; we interpolate the main diagonal along the diagonal
outdiag = interpolate(sdiag,floc)
badph = where(~ goodph,nbad)
if nbad gt 0 then begin
    dist = max([[mindate-phases],[phases-maxdate]],dimension=2)
    x = dist[badph]
    if min(x) lt 0 then $
      message,' something is not right...'
    ; this allows for slop at the ends (no sharp jumps in the chisq!)
    ;   but it won't let the fit go off the edge of the world
    outdiag[badph] = outdiag[badph] + (sqrt(x)*(exp(-((x-13)/8d)^4)*15d) > 0.0d)
endif

out = interpolate(sall,floc,floc,/grid)
zn = dblarr(n)
for i=0,n-1 do begin
  if not goodph[i] then begin
     out[*,i] = zn
     out[i,*] = zn
  endif
endfor
for i=0,n-1 do out[i,i] = outdiag[i]

; the interpolation isn't quite symmetric enough for eigenql (~1d-18)
; so we symmetrize the matrix here
out = (out + transpose(out))/2.0d

return,out

end

