function gx_getfilename,z,rfcolname,obsf,sample,rfcolset,extlaw,rv

;
; gx_getfilename.pro -- determines the Galactic extinction table filename
;
; Created 2005-Nov-14
; Version 2005-Nov-18
;               
; INPUTS
;         z: redshift (scalar)
; rfcolname: rest-frame color name (string: 
;                                  'U-B', 'B-V', 'V-R', 'R-I', or 'V-I')
;      obsf: observer-frame passband (string or passband structure)
;    sample: spectral sample (string)
;  rfcolset: rest-frame color set (string)
;
; OPTIONAL INPUTS
;    extlaw: extinction law 'CCM' (default) or 'FM' (using fm_unred.pro)
;        rv: R_V to use (default: 3.1)
;     
; RETURN VALUE
;  filename for Galactic extinction correction lookup table
;

if n_elements(extlaw) eq 0 then extlaw = 'CCM'
if n_elements(rv) eq 0 then rv = 3.1

if size(obsf,/tname) eq 'STRING' then $
  obsfstr = translatepb(obsf) $
else obsfstr = obsf.name

return, 'aux/galext/' + $
  strcompress(sample,/remove_all)+'/' + $
  'gx.z=' + $
  strcompress(string(z,format='(f0.3)'),/remove_all) + '.' + $
  strcompress(obsfstr,/remove_all) + '.' + $
  strcompress(rfcolname,/remove_all) + '.' + $
  strcompress(rfcolset,/remove_all) + '.' + $
  strcompress(extlaw,/remove_all) + '.' + $
  'R_V=' + strcompress(string(rv,format='(f0.1)'),/remove_all) + $
  '.fits'

end
