pro gx_lookup, table, ph, ebv, rfcol, outgx, outsig, index=index
;
; gx_lookup.pro -- interpolates a Galactic extinction lookup table for the
;                  desired phases and colors
;
; Created 2005-Nov-14
; Version 2006-Aug-10
;               
; INPUTS
;     table: Galactic extinction lookup table structure(s)
;        ph: rest-frame phases (scalar or array)
;       ebv: scalar
;     rfcol: rest-frame colors matching phases (scalar or array)
;     
; OPTIONAL INPUT:
;     index: if table is an array, what index of that array to use
;            (this allows us to pass by reference, and avoids copying
;             this large structure in memory repeatedly, saving a lot
;             of time)
;
; OUTPUTS
;     outgx: computed Galactic extinctions (same # of elements as ph and rfcol)
;    outsig: internal uncertainty (same # of elements as ph and rfcol)
;

if n_elements(index) ne 1 then index = 0

np = table[index].nphase
nic = table[index].nicoeffs
nsc = table[index].nscoeffs

; set up for the interpolation
plocarr = interpol(dindgen(np),table[index].phase,ph)


; calculate slope and intercept
n = n_elements(ph)
intercept = dblarr(n)
slope = dblarr(n)

for i=0,nic-1 do intercept += (rfcol^i)*interpolate(reform(table[index].icoeffs[i,*]),plocarr)
for i=0,nsc-1 do slope += (rfcol^i)*interpolate(reform(table[index].scoeffs[i,*]),plocarr)

; calculate extinction correction and uncertainty
outgx = ebv*(intercept + slope*ebv)
outsig = ebv*(table[index].isig + abs(slope)*table[index].ssig)

; flag out of bounds points
bad = where(ph lt min(table[index].phase) or $
            ph gt max(table[index].phase) or $
            rfcol lt table[index].mincolor or $
            rfcol gt table[index].maxcolor, nbad) 

if nbad gt 0 then begin
    outgx[bad] = -999.999
    outsig[bad] = 999.999
endif

end
