pro gx_parsefilename,fn,z,rfcolname,obsf,sample,rfcolset,extlaw,rv

;
; gx_parsefilename.pro -- breaks down the Galactic extinction filename
;
; Created 2005-Nov-14
; Version 2005-Nov-18
;               
; INPUTS
;        fn: Galactic extinction lookup table filename, e.g.,
;           aux/galext/normal/gx.z=0.032.R_Bessell.V-R.Bessell.CCM.R_V=3.1.fits
;
; OUTPUTS
;
;         z: redshift
; rfcolname: rest-frame color name 
;      obsf: observer-frame passband (string)
;    sample: spectral sample (string)
;  rfcolset: rest-frame color set (string)
;    extlaw: extinction law 
;        rv: R_V 
;     

p = strsplit(fn,'.',/extract,count=np)

sample = (strsplit(p[0],'/',/extract))[2]

qq = where(strmid(p,0,2) eq 'z=',nqq)
if nqq ne 1 then message,' cannot parse fn: '+fn
qq = qq[0]
z = float( (strsplit(strjoin(p[qq:qq+1],'.'),'=',/extract))[1] )

qq = where(strmid(p,0,4) eq 'R_V=',nqq)
if nqq ne 1 then message,' cannot parse fn: '+fn
qq = qq[0]
rv = float( (strsplit(strjoin(p[qq:qq+1],'.'),'=',/extract))[1] )

obsf = p[qq-4]
rfcolname = p[qq-3]
rfcolset = p[qq-2]
extlaw = p[qq-1]

end
