function gx_readfits,fn,verbose=verbose
;
; gx_readfits.pro -- read the Galactic extinction lookup table fits file
;
;  This is a helper routine for gx_loadfile; don't use this directly.
;
; Created 2005-Nov-14
; Version 2005-Nov-18
;               
; INPUTS
;        fn: full path to fits file, e.g.,
;             /m2dir/aux/galext/normal/gx.z=0.032.R_Bessell.V-R.Bessell.CCM.R_V=3.1.fits

;
; KEYWORDS
;   verbose: print out informational messages from MRDFITS
;     
; RETURN VALUE
;  Galactic extinction lookup table structure (standardized)
;

silent = (keyword_set(verbose)) ? 0 : 1

icoeffs = mrdfits(fn,0,hdr,silent=silent)
scoeffs = mrdfits(fn,1,silent=silent)
phase = mrdfits(fn,2,silent=silent)

out = { gx_lookup_std, $
        filename: fn, $
        obsf: strtrim(sxpar(hdr,'OBSPB'),2), $
        rfcolname: strtrim(sxpar(hdr,'RESTCOLN'),2), $
        rfcolset: strtrim(sxpar(hdr,'RESTCOLS'),2), $
        sample: strtrim(sxpar(hdr,'SPECSAMP'),2), $
        z: float(sxpar(hdr,'REDSHIFT')), $
        extlaw: strtrim(sxpar(hdr,'EXTNCLAW'),2), $
        rv: float(sxpar(hdr,'RV')), $
        mincolor: float(sxpar(hdr,'COLORMIN')), $
        maxcolor: float(sxpar(hdr,'COLORMAX')), $
        nicoeffs: long(sxpar(hdr,'NICOEFFS')), $
        nscoeffs: long(sxpar(hdr,'NSCOEFFS')), $
        nphase: long(sxpar(hdr,'NPHASE')), $
        icoeffs: icoeffs, $
        scoeffs: scoeffs, $
        isig: float(sxpar(hdr,'IUNCERT')), $
        ssig: float(sxpar(hdr,'SUNCERT')), $
        phase: phase }


return,out


end
