pro gx_writefits,fn,inphase,nphase,incolor,inicoeffs,inscoeffs $
                 ,inisig,inssig $
                 ,inz,rfcolname,obsf,sample,rfcolset,extlaw,inrv $
                 ,nspc,inavgtossed $
                 ,overwrite=overwrite
;
; gx_writefits.pro -- write the Galactic extinction lookup table fits file
;
;  This is a helper routine for gx_createfile; don't use this directly.
;
; Created 2005-Nov-14
; Version 2005-Nov-18
;               
; INPUTS
;        fn: full path to fits file, e.g.,
;             /m2dir/aux/galext/normal/gx.z=0.032.R_Bessell.V-R.Bessell.CCM.R_V=3.1.fits
;   inphase: phase array
;    nphase: number of elements in phase array
;   incolor: color array
; inicoeffs: coefficients for Galactic extinction intercept
; inscoeffs: coefficients for Galactic extinction slope
;    inisig: intercept uncertainity
;    inssig: slope uncertainity
;       inz: redshift
; rfcolname: rest-frame color name
;      obsf: observer-frame passband name
;    sample: spectral sample
;  rfcolset: rest-frame color set
;    extlaw: extinction law
;      inrv: R_V
;      nspc: number of spectra used in calculation
; inavgtossed: average number of rejected spectra
;
; KEYWORDS
; overwrite: if set, will overwrite existing fits file
;     

overwrite = keyword_set(overwrite)
if not overwrite then $
  if file_test(fn) then $
    message,'file already exists, use /overwrite: '+fn

outdir = file_dirname(fn)
if not file_test(outdir,/directory) then file_mkdir,outdir

phase = float(inphase)
color = float(incolor)
icoeffs = float(inicoeffs)
scoeffs = float(inscoeffs)
isig = float(inisig)
ssig = float(inssig)
z = float(inz)
rv = float(inrv)
avgtossed = float(inavgtossed)

nic = n_elements(icoeffs[*,0])
nsc = n_elements(scoeffs[*,0])

sxaddpar,hdr,'OBSPB',obsf,' observer-frame passband'
sxaddpar,hdr,'RESTCOLN',rfcolname,' rest-frame color name'
sxaddpar,hdr,'RESTCOLS',rfcolset,' rest-frame color set'
sxaddpar,hdr,'SPECSAMP',sample,' spectral sample directory'
sxaddpar,hdr,'REDSHIFT',z,' redshift',format='F19.3'
sxaddpar,hdr,'EXTNCLAW',extlaw,' extinction law (IDL: EXTNCLAW_unred.pro)'
sxaddpar,hdr,'RV',rv,' R_V',format='F19.1'
sxaddpar,hdr,'COLORMIN',min(color),' minimum valid rest-frame color',format='F19.2'
sxaddpar,hdr,'COLORMAX',max(color),' maximum valid rest-frame color',format='F19.2'
sxaddpar,hdr,'NICOEFFS',nic,' number of intercept coefficients',format='I19'
sxaddpar,hdr,'NSCOEFFS',nsc,' number of slope coefficients',format='I19'
sxaddpar,hdr,'NPHASE',nphase,' number of elements in phase array',format='I19'
sxaddpar,hdr,'NSPECTRA',nspc,' number of spectra used in calculation',format='I19'
sxaddpar,hdr,'AVGTOSSD',avgtossed,' average number of rejected spectra' $
        ,format='F19.1'
sxaddpar,hdr,'IUNCERT',isig,' internal intercept uncertainty',format='F19.6'
sxaddpar,hdr,'SUNCERT',ssig,' internal slope uncertainty',format='F19.6'
fxaddpar,hdr,'COMMENT',' '
fxaddpar,hdr,'COMMENT',' Galactic extinction lookup table'
fxaddpar,hdr,'COMMENT',' '
fxaddpar,hdr,'COMMENT','   file format:'
fxaddpar,hdr,'COMMENT','     primary: NICOEFFS by NPHASE Galactic extinction intercept array'
fxaddpar,hdr,'COMMENT','       ext 1: NSCOEFFS by NPHASE Galactic extinction slope array'
fxaddpar,hdr,'COMMENT','       ext 2: NPHASE element phase array'
fxaddpar,hdr,'COMMENT',' '
sxaddhist,'Created using gx_writefits.pro at UT ' + systime(/utc),hdr
sxaddhist,'Created by ' + getenv('USER') + '@' + getenv('HOST'),hdr

; create fits file with Galactic extinction intercept coefficients
mwrfits,icoeffs,fn,hdr,/create

; extension 1 is the Galactic extinction slope coefficients
mwrfits,scoeffs,fn

; extension 2 is the phase array
mwrfits,phase,fn

end
