function kc_loadfile, fn, std=std
;
; kc_loadfile.pro -- load a K-correction lookup table
;
; Created 2005-Nov-09
; Version 2005-Nov-12
;               
; INPUTS
;        fn: lookup table file name 
;            (e.g., aux/kcorr/normal/kc.z=0.123.B_Bessell.to.B_Bessell.B-V.Bessell.fits)
;
; KEYWORDS
;       std: return structure in a standardized format
;              i.e., make the color array always a fixed size, so you
;              can create an array of different lookup table structures
;     
; RETURN VALUE
;  K-correction lookup table structure
;

std = keyword_set(std)

m2dir = getenv('MLCS2K2_BASEDIR') + '/'
fullfn = m2dir + fn

; if this K-correction has not been computed we have to do it
if not file_test(fullfn) then kc_createfile,fn

; load it up
out = kc_readfits(fullfn)

; and return it
if not std then return,out


; if we are standardizing the structures the arrays inside them
;   need to have the same number of elements. this will let you
;   create an array of kc_lookup_std structures, 
ncolmax = 140l
nphase = out.nphase
ncolor = out.ncolor

newkc = fltarr(nphase,ncolmax) - 9999.999
newcolor = fltarr(ncolmax) - 9999.999
newksig = fltarr(ncolmax) + 9999.999

newcolor[0:ncolor-1] = out.color
newksig[0:ncolor-1] = out.ksig

for i=0,nphase-1 do newkc[i,0:ncolor-1] = out.kc[i,*]

nout = { kc_lookup_std, $
         filename: out.filename, $
         rf: out.rf, $
         obsf: out.obsf, $
         rfcolname: out.rfcolname, $
         rfcolset: out.rfcolset, $
         sample: out.sample, $
         z: out.z, $
         nphase: nphase, $
         ncolor: ncolor, $
         ncolmax: ncolmax, $
         kc: newkc, $
         phase: out.phase, $
         color: newcolor, $
         ksig: newksig }

return,nout

end
