pro kc_lookup, table, ph, rfcol, outkc, outsig, index=index
;
; kc_lookup.pro -- interpolates a K-correction lookup table for the
;                  desired phases and colors
;
; Created 2005-Nov-11
; Version 2006-Aug-10
;               
; INPUTS
;     table: K-correction lookup table structure(s)
;        ph: rest-frame phases (scalar or array)
;     rfcol: rest-frame colors matching phases (scalar or array)
;     
; OPTIONAL INPUT:
;     index: if table is an array, what index of that array to use
;            (this allows us to pass by reference, and avoids copying
;             this large structure in memory repeatedly, saving a lot
;             of time)
; OUTPUTS
;     outkc: computed K-corrections (same # of elements as ph and rfcol)
;    outsig: K-correction uncertainty (same # of elements as ph and rfcol)
;

if n_elements(index) ne 1 then index = 0

np = table[index].nphase
nc = table[index].ncolor

; set up for the interpolation
plocarr = interpol(dindgen(np),table[index].phase,ph)
clocarr = interpol(dindgen(nc),table[index].color[0:nc-1],rfcol)

; bilinear interpolation to get the K-correction
outkc = interpolate(table[index].kc,plocarr,clocarr,missing=-999.999)

; linear interpolation to get the K-correction uncertainty
outsig = interpolate(table[index].ksig,clocarr,missing=999.999)

end
