function kc_readfits,fn,verbose=verbose
;
; kc_readfits.pro -- read the K-correction lookup table fits file
;
;  This is a helper routine for kc_loadfile; don't use this directly.
;
; Created 2005-Nov-10
; Version 2005-Nov-12
;               
; INPUTS
;        fn: full path to fits file
;            (e.g., /m2dir/aux/kcorr/normal/kc.z=0.123.B_Bessell.to.B_Bessell.B-V.Bessell.fits)
;
; KEYWORDS
;   verbose: print out informational messages from MRDFITS
;     
; RETURN VALUE
;  K-correction lookup table structure (not standardized)
;

silent = (keyword_set(verbose)) ? 0 : 1

kc = mrdfits(fn,0,hdr,silent=silent)
phase = mrdfits(fn,1,silent=silent)
color = mrdfits(fn,2,silent=silent)
ksig = mrdfits(fn,3,silent=silent)

out = { filename: fn, $
        rf: strtrim(sxpar(hdr,'RESTPB'),2), $
        obsf: strtrim(sxpar(hdr,'OBSPB'),2), $
        rfcolname: strtrim(sxpar(hdr,'RESTCOLN'),2), $
        rfcolset: strtrim(sxpar(hdr,'RESTCOLS'),2), $
        sample: strtrim(sxpar(hdr,'SPECSAMP'),2), $
        z: float(sxpar(hdr,'REDSHIFT')), $
        nphase: long(sxpar(hdr,'NPHASE')), $
        ncolor: long(sxpar(hdr,'NCOLOR')), $
        kc: kc, $
        phase: phase, $
        color: color, $
        ksig: ksig }

return,out


end
