pro kc_writefits,fn,inphase,nphase,incolor,ncolor,inkc,inksig $
                 ,inz,rfcolname,rf,obsf,sample,rfcolset $
                 ,nspc,inavgtossed $
                 ,overwrite=overwrite
;
; kc_writefits.pro -- write the K-correction lookup table fits file
;
;  This is a helper routine for kc_createfile; don't use this directly.
;
; Created 2005-Nov-10
; Version 2005-Nov-18
;               
; INPUTS
;        fn: full path to fits file
;            (e.g., /m2dir/aux/kcorr/normal/kc.z=0.123.B_Bessell.to.B_Bessell.B-V.Bessell.fits)
;   inphase: phase array
;    nphase: number of elements in phase array
;   incolor: color array
;    ncolor: number of elements in color array
;      inkc: 2-d K-correction array [nphase,ncolor]
;    inksig: K-correction uncertainty array [ncolor]
;       inz: redshift
; rfcolname: rest-frame color name
;        rf: rest-frame passband name
;      obsf: observer-frame passband name
;    sample: spectral sample
;  rfcolset: rest-frame color set
;      nspc: number of spectra used in K-correction calculation
; inavgtossed: average number of rejected spectra
;
; KEYWORDS
; overwrite: if set, will overwrite existing fits file
;     

overwrite = keyword_set(overwrite)
if not overwrite then $
  if file_test(fn) then $
    message,'file already exists, use /overwrite: '+fn

outdir = file_dirname(fn)
if not file_test(outdir,/directory) then file_mkdir,outdir

phase = float(inphase)
color = float(incolor)
kc = float(inkc)
ksig = float(inksig)
z = float(inz)
avgtossed = float(inavgtossed)

sxaddpar,hdr,'RESTPB',rf,' rest-frame passband'
sxaddpar,hdr,'OBSPB',obsf,' observer-frame passband'
sxaddpar,hdr,'RESTCOLN',rfcolname,' rest-frame color name for color array'
sxaddpar,hdr,'RESTCOLS',rfcolset,' rest-frame color set for color array'
sxaddpar,hdr,'SPECSAMP',sample,' spectral sample directory'
sxaddpar,hdr,'REDSHIFT',z,' redshift',format='F19.3'
sxaddpar,hdr,'NPHASE',nphase,' number of elements in phase array',format='I19'
sxaddpar,hdr,'NCOLOR',ncolor,' number of elements in color array',format='I19'
sxaddpar,hdr,'NSPECTRA',nspc,' number of spectra used in calculation',format='I19'
sxaddpar,hdr,'AVGTOSSD',avgtossed,' average number of rejected spectra' $
        ,format='F19.1'
fxaddpar,hdr,'COMMENT',' '
fxaddpar,hdr,'COMMENT',' K-correction lookup table'
fxaddpar,hdr,'COMMENT',' '
fxaddpar,hdr,'COMMENT','   file format:'
fxaddpar,hdr,'COMMENT','     primary: NPHASE by NCOLOR K-correction array'
fxaddpar,hdr,'COMMENT','       ext 1: NPHASE element phase array'
fxaddpar,hdr,'COMMENT','       ext 2: NCOLOR element color array RESTCOLN_RESTCOLS'
fxaddpar,hdr,'COMMENT','       ext 3: NCOLOR element K-correction uncertainty array'
fxaddpar,hdr,'COMMENT',' '
sxaddhist,'Created using kc_writefits.pro at UT ' + systime(/utc),hdr
sxaddhist,'Created by ' + getenv('USER') + '@' + getenv('HOST'),hdr

; create fits file with K-correction "image" in primary unit
mwrfits,kc,fn,hdr,/create

; extension 1 is the phase array
mwrfits,phase,fn

; extension 2 is the color array
mwrfits,color,fn

; extension 3 is the k-correction uncertainty (sigma)
mwrfits,ksig,fn

end
