function pbefflam, pb

; This routine calculates the effective wavelength for a passband
; There are different conventions for how to do this; here we use Rick
; Kessler's convention:
;
; For photon units, 
; 
;    efflam = sum(T*lambda)/sum(T).
; For energy units, then
;
;    T' = T(energy)/lambda   [convert to count-transmission]
;
; and
;    efflam = sum(T'*lambda)/sum(T')
;           = sum(T)/sum(T/lambda)
;
; GM, 12/2006 -- updated sj 2007-Feb-20
;-

if size(pb,/tname) eq 'STRING' then pbs = getpb(pb) else pbs = pb

if pbs.respunit eq 'photons' then begin
    efflam = total(pbs.response*pbs.wavelength)/total(pbs.response)
endif else if pbs.respunit eq 'ergs' then begin
    efflam = total(pbs.response)/total(pbs.response/pbs.wavelength)
endif else begin
    message,'unknown response unit in passband: ' + pbs.respunit
endelse

return, efflam

end
