pro plotfit,sn,fitout,obsframefn,gridfn=gridfn,psfn=psfn

ps = (n_elements(psfn) eq 1) ? 1 : 0

if ps then ps_open,filename=psfn else window,xsize=1000,ysize=750

opb = ''
readit,obsframefn,opb,t,mag,err,nelems=n
;opb = strupcase(opb)

obspb = opb[uniq(opb,sort(opb))]
restpb = bestrest(obspb, fitout.info.z, lameff=lameff)
s = sort(lameff)
obspb = obspb[s]
restpb = restpb[s]
lameff = lameff[s]

nuniqf = n_elements(obspb)

data = readlcdata(sn,obspb=datapb)

fit = fitout.param

t -= fit[0]
data.jd -= fit[0]

z1 = (1.0d + fitout.info.z)
xr = auto_range([-10*z1,data.jd,40*z1],factor=0.1) 
xr = (xr < 125.0d*z1) > (-30.0d*z1)
onplot = where(data.jd gt xr[0] and data.jd lt xr[1],nonplot)
if nonplot le 0 then message,'no valid data?'
yr = reverse(auto_range(data[onplot].mag,factor=0.2))

graylev  = ps ? 0.65d : 0.35d
graylev2 = ps ? 0.82d : 0.18d
graylev3 = ps ? 0.94d : 0.06d
xcs = ps ? 2.1 : 2.5
ycs = xcs
textcs = ps ? 1.1 : 1.3
th = ps ? 4.0 : 1.0

gray = rgb(graylev,graylev,graylev,/normal)
gray2 = rgb(graylev2,graylev2,graylev2,/normal)
gray3 = rgb(graylev3,graylev3,graylev3,/normal)

oldp = !p
oldx = !x
oldy = !y

!x.margin = [20,5]
!y.margin = [8,3]

!p.multi = [0,2,3]

!p.thick = th
!x.thick = th
!y.thick = th
!p.charthick = th

t0str = 't!D0!N'
rvstr = 'R!DV!N'
delstr = '!7D!N!3'
avstr = 'A!DV!N'
mu0str = '!7l!3!D0!N + 5 log (H!D0!N/65)'
m0str = 'm!DV!U0!N'

xttl = 'HJD - ' + string(fit[0],format='(f0.3)')

for f=0,nuniqf-1 do begin

    nowf = obspb[f]
    
    yttl = nowf + ' mag (rest:' + restpb[f] + ')'

    plot,[0],[0],/nodata,xr=xr,yr=yr,/xst,ytitle=yttl,$
      xcharsize=xcs,ycharsize=ycs,xtitle=xttl,/yst

    w = where(opb eq nowf)

    xmod = t[w]
    ymod = mag[w]
    ysig = err[w]

    s = sort(xmod)
    xmod = xmod[s]
    ymod = ymod[s]
    ysig = ysig[s]

    polyfill,[xmod,reverse(xmod)],[ymod+ysig,reverse(ymod-ysig)],$
      color=gray,noclip=0
    oplot,xmod,ymod
;    oplot,xmod,ymod+ysig,linestyle=2
;    oplot,xmod,ymod-ysig,linestyle=2

    w = where(data.obspbname eq nowf,nw)

    if nw gt 0 then begin

        oplot, [data[w].jd], [data[w].mag], psym=4
        ebplot, [data[w].jd], [data[w].mag], [data[w].err]

        for j=0,nw-1 do begin
          
           xx = w[j] 
           qq = where( fitout.data.obspbname eq data[xx].obspbname and $
                       abs(fitout.data.jd-fit[0]-data[xx].jd) lt 1d-4 and $
                       abs(fitout.data.mag-data[xx].mag) lt 1d-4, nqq)
	   if nqq eq 0 then oplot,[data[xx].jd],[data[xx].mag],psym=7,symsize=1.3

        endfor

    endif

    if ((f mod 5) eq 4) or (f eq nuniqf-1) then begin

        xyouts,0.75,0.290,/normal,sn,charsize=textcs*1.5,charthick=th*1.5,align=0.5

        str = t0str + ' = ' + string(fit[0],format='(f0.3)') + '   '+rvstr+' = ' + $
          string(fit[2],format='(f5.2)')
        xyouts,0.75,0.230,/normal,str,charsize=textcs,charthick=th,align=0.5

        str = delstr+' = ' + string(fit[1],format='(f5.2)') + '   '+avstr+' = ' + $
          string(fit[4],format='(f5.2)')
        xyouts,0.75,0.195,/normal,str,charsize=textcs,charthick=th,align=0.5

        str = mu0str + ' = ' + string(fit[3],format='(f5.2)') ;  + $
        ;  ' !9+!3 ' + string(sqrt(cq[0,0]),format='(f4.2)')
        xyouts,0.75,0.160,/normal,str,charsize=textcs,charthick=th,align=0.5

        str = 'E(B-V)!DMW!N = ' + string(fitout.info.ebvsfd,format='(f0.2)') + '    ' + $
          'z = ' + string(fitout.info.z,format='(f0.4)')
        xyouts,0.75,0.125,/normal,str,charsize=textcs,charthick=th,align=0.5

        str = '!7v!3!U2!N/!7m!3 = ' + string(fitout.mincs-fitout.prisq,format='(f7.2)') + $
          '/' + string(fitout.ndof,format='(i0)')
        xyouts,0.75,0.090,/normal,str,charsize=textcs,charthick=th,align=0.5

        if (not ps) and (f ne nuniqf-1) then begin
            junk = ''
            read, 'press any key to continue... ', junk
        endif

        !p.multi = [0,2,3]

    endif

endfor

if n_elements(gridfn) ne 0 then begin

    restore,gridfn

    if not ps then begin
        junk = ''
        read, 'press any key to continue... ', junk
    endif

    zeropt = getzeropoint(fitout.info.vecname)

    ot0str = t0str
    t0str = t0str + ' - ' + string(t0mean,format='(f0.3)')
    t0 -= t0mean

    !p.multi = [0,2,3]

    plot,mu0,pmu0,xtitle=mu0str,ytitle='probability' $
      ,xcharsize=xcs,ycharsize=ycs,psym=-4,xstyle=8
    oplot,[mu0mean,mu0mean],!y.crange,linestyle=2
    oplot,[mu0mean,mu0mean]+mu0sd,!y.crange,linestyle=1
    oplot,[mu0mean,mu0mean]-mu0sd,!y.crange,linestyle=1
    axis,0,!y.crange[1],/xaxis,xr=!x.crange+zeropt $ ;,xtitle='m!D0!N' $
      ,xcharsize=xcs,xstyle=1

    plot,av0,pav0,xtitle=avstr,ytitle='probability' $
      ,xcharsize=xcs,ycharsize=ycs,psym=-4
    oplot,[av0mean,av0mean],!y.crange,linestyle=2
    oplot,[av0mean,av0mean]+av0sd,!y.crange,linestyle=1
    oplot,[av0mean,av0mean]-av0sd,!y.crange,linestyle=1

    plot,del,pdel,xtitle=delstr,ytitle='probability' $
      ,xcharsize=xcs,ycharsize=ycs,psym=-4
    oplot,[delmean,delmean],!y.crange,linestyle=2
    oplot,[delmean,delmean]+delsd,!y.crange,linestyle=1
    oplot,[delmean,delmean]-delsd,!y.crange,linestyle=1

    plot,t0,pt0,xtitle=t0str,ytitle='probability', $
      xcharsize=xcs,ycharsize=ycs,psym=-4
    oplot,[0d,0d],!y.crange,linestyle=2
    oplot,[0d,0d]+t0sd,!y.crange,linestyle=1
    oplot,[0d,0d]-t0sd,!y.crange,linestyle=1

    plot,rv,prv,xtitle=rvstr,ytitle='probability' $
      ,xcharsize=xcs,ycharsize=ycs,psym=-4
    oplot,[rvmean,rvmean],!y.crange,linestyle=2
    oplot,[rvmean,rvmean]+rvsd,!y.crange,linestyle=1
    oplot,[rvmean,rvmean]-rvsd,!y.crange,linestyle=1


    xyouts,0.75,0.29,/normal,sn,charsize=textcs*1.5,charthick=th*1.5,align=0.5

    str = mu0str + ' = ' + string(mu0mean,format='(f5.2)') + ' !9+!3 ' + $
      string(mu0sd,format='(f4.2)')
    xyouts,0.75,0.230,/normal,str,charsize=textcs,charthick=th,align=0.5
    
    str = m0str + ' = ' + string(m0mean,format='(f5.2)') + ' !9+!3 ' + $
      string(m0sd,format='(f4.2)')
    xyouts,0.75,0.195,/normal,str,charsize=textcs,charthick=th,align=0.5

    str = delstr + ' = ' + string(delmean,format='(f5.2)') + ' !9+!3 ' + $
      string(delsd,format='(f4.2)')
    xyouts,0.75,0.160,/normal,str,charsize=textcs,charthick=th,align=0.5

    str = avstr + ' = ' + string(av0mean,format='(f5.2)') + ' !9+!3 ' + $
      string(av0sd,format='(f4.2)')
    xyouts,0.75,0.125,/normal,str,charsize=textcs,charthick=th,align=0.5

    str = rvstr + ' = ' + string(rvmean,format='(f5.2)') + ' !9+!3 ' + $
      string(rvsd,format='(f4.2)')
    xyouts,0.75,0.090,/normal,str,charsize=textcs,charthick=th,align=0.5

    str = ot0str + ' = ' + string(t0mean,format='(f8.2)') + ' !9+!3 ' + $
      string(t0sd,format='(f4.2)')

    p0mean = (t0mean - fitout.startparam[0])/(1.0d + fitout.info.z)
    p0sgn = (p0mean < 0.0d) ? '-' : '+'
    str = str + '   (' + p0sgn + string(abs(p0mean),format='(f4.2)') + $
  ' !9+!3 ' + string(t0sd/(1.0d + fitout.info.z),format='(f4.2)') + ')'
    xyouts,0.75,0.055,/normal,str,charsize=textcs,charthick=th,align=0.5

    if not ps then begin
        junk = ''
        read, 'press any key to continue... ', junk
    endif


    qq = [nt0,ndel,nrv,nmu0,nav0]
    junk = where(qq gt 1,nparam)

    if nparam gt 1 then begin
    
        !y.margin = [8,4]
        sigmas = [3.0d,2.5d,2.0d,1.5d,1.0d,0.5d,1d-4]
        wantlevels = 2.0d * gauss_pdf(sigmas) - 1.0d
        lstyle = [0,1,0,1,0,1,0]

        fillind = [0,2,4] ; indices of sigmas to fill: 3sig, 2sig, 1sig
        fcolor = [gray3,gray2,gray]

        case nparam of
            2: !p.multi = 0     ; 1 plot
            3: begin
                  !p.multi = [0,2,2] ; 3 plots
                  xcs /= 1.5
                  ycs /= 1.5
                  !x.margin /= 1.5
                  !y.margin /= 1.5
               end
            4: !p.multi = [0,2,3] ; 6 plots
            5: !p.multi = [0,2,3] ; 10 plots -- use 2 pages 
        endcase

        if nmu0 gt 1 then begin

            if nav0 gt 1 then begin
                prob = dblarr(nmu0,nav0)
                for i=0,nmu0-1 do for j=0,nav0-1 do $
                  prob[i,j] = total(pgrid[*,*,*,i,j])*dt0*ddel*drv

                levs = getlevels(prob,dmu0*dav0,wantlevels,/increase)
                
                contour,prob,mu0,av0,xcharsize=xcs,ycharsize=ycs,xstyle=8 $
                  ,xtitle=mu0str,ytitle=avstr,/closed $
                  ,levels=levs[fillind],c_color=fcolor,/fill

                contour,prob,mu0,av0,xcharsize=xcs,ycharsize=ycs,xstyle=8 $
                  ,xtitle=mu0str,ytitle=avstr,/closed $
                  ,levels=levs,c_linestyle=lstyle,/overplot
 
                axis,0,!y.crange[1],/xaxis,xr=!x.crange+zeropt $ 
                  ,xcharsize=xcs,xstyle=1 ;,xtitle='m!D0!N' 
            endif

            xyouts,0.535,0.00,/normal,sn,charsize=textcs*1.5 $
              ,charthick=th*1.5,align=0.5

            if ndel gt 1 then begin
                prob = dblarr(nmu0,ndel)
                for i=0,nmu0-1 do for j=0,ndel-1 do $
                  prob[i,j] = total(pgrid[*,j,*,i,*])*dt0*drv*dav0

                levs = getlevels(prob,dmu0*ddel,wantlevels,/increase)

                contour,prob,mu0,del,xcharsize=xcs,ycharsize=ycs,xstyle=8 $
                  ,xtitle=mu0str,ytitle=delstr,/closed $
                  ,levels=levs[fillind],c_color=fcolor,/fill

                contour,prob,mu0,del,xcharsize=xcs,ycharsize=ycs,xstyle=8 $
                  ,xtitle=mu0str,ytitle=delstr,/closed $
                  ,levels=levs,c_linestyle=lstyle,/overplot
 
                axis,0,!y.crange[1],/xaxis,xr=!x.crange+zeropt $ 
                  ,xcharsize=xcs,xstyle=1 ;,xtitle='m!D0!N' 
            endif


            if nt0 gt 1 then begin
                prob = dblarr(nmu0,nt0)
                for i=0,nmu0-1 do for j=0,nt0-1 do $
                  prob[i,j] = total(pgrid[j,*,*,i,*])*ddel*drv*dav0

                levs = getlevels(prob,dmu0*dt0,wantlevels,/increase)

                contour,prob,mu0,t0,xcharsize=xcs,ycharsize=ycs,xstyle=8 $
                  ,xtitle=mu0str,ytitle=t0str,/closed $
                  ,levels=levs[fillind],c_color=fcolor,/fill

                contour,prob,mu0,t0,xcharsize=xcs,ycharsize=ycs,xstyle=8 $
                  ,xtitle=mu0str,ytitle=t0str,/closed $
                  ,levels=levs,c_linestyle=lstyle,/overplot
 
                axis,0,!y.crange[1],/xaxis,xr=!x.crange+zeropt $ 
                  ,xcharsize=xcs,xstyle=1 ;,xtitle='m!D0!N' 
            endif



            if nrv gt 1 then begin
                prob = dblarr(nmu0,nrv)
                for i=0,nmu0-1 do for j=0,nrv-1 do $
                  prob[i,j] = total(pgrid[*,*,j,i,*])*dt0*ddel*dav0

                levs = getlevels(prob,dmu0*drv,wantlevels,/increase)
                
                contour,prob,mu0,rv,xcharsize=xcs,ycharsize=ycs,xstyle=8 $
                  ,xtitle=mu0str,ytitle=rvstr,/closed $
                  ,levels=levs[fillind],c_color=fcolor,/fill

                contour,prob,mu0,rv,xcharsize=xcs,ycharsize=ycs,xstyle=8 $
                  ,xtitle=mu0str,ytitle=rvstr,/closed $
                  ,levels=levs,c_linestyle=lstyle,/overplot
 
                axis,0,!y.crange[1],/xaxis,xr=!x.crange+zeropt $ 
                  ,xcharsize=xcs,xstyle=1 ;,xtitle='m!D0!N' 
            endif

        endif
    
        if nav0 gt 1 then begin

            if ndel gt 1 then begin
                prob = dblarr(nav0,ndel)
                for i=0,nav0-1 do for j=0,ndel-1 do $
                  prob[i,j] = total(pgrid[*,j,*,*,i])*dt0*drv*dmu0

                levs = getlevels(prob,dav0*ddel,wantlevels,/increase)

                contour,prob,av0,del,xcharsize=xcs,ycharsize=ycs $
                  ,xtitle=avstr,ytitle=delstr,/closed $
                  ,levels=levs[fillind],c_color=fcolor,/fill

                contour,prob,av0,del,xcharsize=xcs,ycharsize=ycs $
                  ,xtitle=avstr,ytitle=delstr,/closed $
                  ,levels=levs,c_linestyle=lstyle,/overplot
            endif

            if nt0 gt 1 then begin
                prob = dblarr(nav0,nt0)
                for i=0,nav0-1 do for j=0,nt0-1 do $
                  prob[i,j] = total(pgrid[j,*,*,*,i])*ddel*drv*dmu0

                levs = getlevels(prob,dav0*dt0,wantlevels,/increase)

                contour,prob,av0,t0,xcharsize=xcs,ycharsize=ycs $
                  ,xtitle=avstr,ytitle=t0str,/closed $
                  ,levels=levs[fillind],c_color=fcolor,/fill

                contour,prob,av0,t0,xcharsize=xcs,ycharsize=ycs $
                  ,xtitle=avstr,ytitle=t0str,/closed $
                  ,levels=levs,c_linestyle=lstyle,/overplot
            endif

            if nrv gt 1 then begin
                prob = dblarr(nav0,nrv)
                for i=0,nav0-1 do for j=0,nrv-1 do $
                  prob[i,j] = total(pgrid[*,*,j,*,i])*dt0*ddel*dmu0

                levs = getlevels(prob,dav0*drv,wantlevels,/increase)

                contour,prob,av0,rv,xcharsize=xcs,ycharsize=ycs $
                  ,xtitle=avstr,ytitle=rvstr,/closed $
                  ,levels=levs[fillind],c_color=fcolor,/fill

                contour,prob,av0,rv,xcharsize=xcs,ycharsize=ycs $
                  ,xtitle=avstr,ytitle=rvstr,/closed $
                  ,levels=levs,c_linestyle=lstyle,/overplot
            endif

        endif
    
        if ndel gt 1 then begin

            if nt0 gt 1 then begin
                prob = dblarr(ndel,nt0)
                for i=0,ndel-1 do for j=0,nt0-1 do $
                  prob[i,j] = total(pgrid[j,i,*,*,*])*drv*dmu0*dav0

                levs = getlevels(prob,ddel*dt0,wantlevels,/increase)

                contour,prob,del,t0,xcharsize=xcs,ycharsize=ycs $
                  ,xtitle=delstr,ytitle=t0str,/closed $
                  ,levels=levs[fillind],c_color=fcolor,/fill

                contour,prob,del,t0,xcharsize=xcs,ycharsize=ycs $
                  ,xtitle=delstr,ytitle=t0str,/closed $
                  ,levels=levs,c_linestyle=lstyle,/overplot
            endif


            if nrv gt 1 then begin
                prob = dblarr(ndel,nrv)
                for i=0,ndel-1 do for j=0,nrv-1 do $
                  prob[i,j] = total(pgrid[*,i,j,*,*])*dt0*dmu0*dav0

                levs = getlevels(prob,ddel*drv,wantlevels,/increase)

                contour,prob,del,rv,xcharsize=xcs,ycharsize=ycs $
                  ,xtitle=delstr,ytitle=rvstr,/closed $
                  ,levels=levs[fillind],c_color=fcolor,/fill

                contour,prob,del,rv,xcharsize=xcs,ycharsize=ycs $
                  ,xtitle=delstr,ytitle=rvstr,/closed $
                  ,levels=levs,c_linestyle=lstyle,/overplot
            endif
            
        endif
    

        if nrv gt 1 then begin

            if nt0 gt 1 then begin
                prob = dblarr(nrv,nt0)
                for i=0,nrv-1 do for j=0,nt0-1 do $
                  prob[i,j] = total(pgrid[j,*,i,*,*])*ddel*dmu0*dav0

                levs = getlevels(prob,drv*dt0,wantlevels,/increase)

                contour,prob,rv,t0,xcharsize=xcs,ycharsize=ycs $
                  ,xtitle=rvstr,ytitle=t0str,/closed $
                  ,levels=levs[fillind],c_color=fcolor,/fill

                contour,prob,rv,t0,xcharsize=xcs,ycharsize=ycs $
                  ,xtitle=rvstr,ytitle=t0str,/closed $
                  ,levels=levs,c_linestyle=lstyle,/overplot
            endif

        endif
    
        xyouts,0.535,0.00,/normal,sn,charsize=textcs*1.5 $
          ,charthick=th*1.5,align=0.5

    endif
    
endif

if ps then ps_close,/noprint

!p = oldp
!x = oldx
!y = oldy

end

