function posdef, c, small=small

; ensures the square matrix c is positive-definite (all positive eigenvalues)

if n_elements(small) eq 0 then small = 1d-5

eigenvals = eigenql(c,eigenvec=evec)
mineig = min(eigenvals)

badvals = where(eigenvals lt small,nbad)
if nbad gt 0 then begin

    ; create a diagonal matrix with the negative eigenvalues replaced
    nevals = diag_matrix(eigenvals > small)

    invevec = invert(evec,stat)
    nc = evec # nevals # invevec
    nc = (nc + transpose(nc))/2.0d

    message,'forcing c to be positive definite, max adjustment: ' + $
      string(max(abs(nc-c))),/info

    out = nc

endif else begin
    out = c
endelse

return, out

end
