pro printfitout, sn, fitout, iter, amoeba=amoeba, grid=grid, outdir=outdir $
               , addobspb=addobspb, baseappend=baseappend

grid = keyword_set(grid) ? 1 : 0
amoeba = keyword_set(amoeba) ? 1 : 0

if total([grid,amoeba]) ne 1 then $
  message,'must set one of /amoeba or /grid'

m2dir = getenv('MLCS2K2_BASEDIR') + '/'
if not keyword_set(outdir) then outdir = m2dir + 'fit/out/' + sn + '/' $
else if strmid(outdir,0,1,/reverse) ne '/' then outdir += '/'

nparam = 5

istr = string(iter,format='(i02)')
if n_elements(baseappend) eq 1 then begin
    notreal = 1
    istr = istr + baseappend
endif else begin
    notreal = 0
endelse

base = outdir + sn + '.iter'+istr

fitoutfn = base+'.fit.out'
if file_test(fitoutfn) then message,fitoutfn+' file already exists?!'


p0 = (fitout.param[0]-fitout.startparam[0])/(1.0d + fitout.info.z)
p0err = fitout.err[0]/(1.0d + fitout.info.z)

fithdr = ';SN                 mu0[H0=65] +/-  av0   +/-     del   +/-      t0    +/-    Rv  +/-     m0v   +/-    p0  +/-'

openw,lun,fitoutfn,/get_lun
printf,lun,fithdr

snbase = sn
while strlen(snbase) le 18 do snbase = snbase + ' '
outs = string(fitout.param[3],format='(f8.3)') + $
       string(fitout.err[3],format='(f6.3)')
outs = outs + string(fitout.param[4],format='(f7.3)') + $
       string(fitout.err[4],format='(f6.3)')
outs = outs + string(fitout.param[1],format='(f8.3)') + $
       string(fitout.err[1],format='(f6.3)')
outs = outs + string(fitout.param[0],format='(f10.2)') + $
       string(fitout.err[0],format='(f5.2)')
outs = outs + string(fitout.param[2],format='(f6.2)') + $
       string(fitout.err[2],format='(f5.2)')
outs = outs + string(fitout.param[3]+getzeropoint(fitout.info.vecname) $
                     ,format='(f8.3)') + $
       string(fitout.err[3],format='(f6.3)')
outs = outs + string(p0,format='(f6.2)') + $
       string(p0err,format='(f5.2)')
printf,lun,snbase + outs

close,lun
free_lun,lun

typestr = (amoeba) ? 'amoeba' : ' grid '

now = systime()

datestr = strmid(now,20,4) + '-' + strmid(now,4,3) + '-' + $
          string(fix(strmid(now,8,2)),format='(i02)') + ' ' + $
          strmid(now,11,8)

endstr = '   ' + datestr + '  ' + typestr

fitlogfn = outdir + sn + '.fit.log'
if not file_test(fitlogfn) then begin
    openw,lun,fitlogfn,/get_lun
    
    flhdr = ';iteration  mu0[H0=65] +/-  av0   +/-     del   +/-      t0    +/-    Rv  +/-     m0v   +/-    p0  +/-        date      time     type'

    
    printf,lun,flhdr
endif else begin
    openw,lun,fitlogfn,/get_lun,/append
endelse

if notreal then begin
    ibase = '#   ' + istr + '  '
endif else begin
    ibase = '    ' + istr + '     '
endelse
printf,lun,ibase+outs+endstr

close,lun

free_lun,lun


rawcs = fitout.mincs - fitout.prisq
rcsred = rawcs/fitout.ndof

out2 =        string(rcsred,format='(f8.4)') 
out2 = out2 + string(fitout.ndof,format='(i8)')
out2 = out2 + string(rawcs,format='(f9.3)')
out2 = out2 + string(fitout.mincs,format='(f9.3)')
out2 = out2 + string(fitout.prisq,format='(f8.3)')
out2 = out2 + string(fitout.csminparam,format='(f12.3,4f8.3)')

mcslogfn = outdir + sn + '.mcs.log'
if not file_test(mcslogfn) then begin

    openw,lun,mcslogfn,/get_lun

    mlhdr1 = ';      minimum chisq from the amoeba or on the grid'
    mlhdr2 = ';iteration red-chisq   ndof   raw-cs    chisq   prisq      t0        del     rv     mu0      av0        date      time     type'

    printf,lun,mlhdr1
    printf,lun,mlhdr2

endif else begin
    openw,lun,mcslogfn,/get_lun,/append

endelse

printf,lun,ibase+out2+endstr

close,lun

free_lun,lun

defaultskcgx, restframeset

out3 =        strjust(fitout.info.vecname,15,/center)
out3 = out3 + ' ' + strjust(fitout.info.specsamp,15,/center)
out3 = out3 + ' ' + strjust(fitout.info.priorpro,15,/center)
out3 = out3 + ' ' + strjust(restframeset,15,/center)

infologfn = outdir + sn + '.info.log'
if not file_test(infologfn) then begin

    openw,lun,infologfn,/get_lun
    
    infhdr = ';iteration' + strjust('vecname',16,/center) + ' ' + $
             strjust('specsamp',16,/center) + $
             strjust('priorpro',16,/center) + $
             strjust('rest-frame set',16,/center) + $
             '      date      time     type'

    printf,lun,infhdr

endif else begin
    openw,lun,infologfn,/get_lun,/append
endelse

printf,lun,ibase+out3+endstr

close,lun
free_lun,lun

restframefn = base+'.restframe.dat'
fullrestlc, fitout.param, fitout.info, restframefn

obsframefn = base+'.obsframe.dat'
fullobslc, fitout.param, fitout.info, fitout.obspb, $
  obsframefn, addobspb=addobspb

datamodfn = base+'.datamodel.dat'
hisnrfn = base+'.hisnr.dat'
datamodel, fitout, datamodfn, hisnrfn=hisnrfn

end
