PRO readit,fn,a00,a01,a02,a03,a04,a05,a06,a07,a08,a09,a10,a11,a12,a13,a14, $
           a15,a16,a17,a18,a19,a20,a21,a22,a23,a24,a25,a26,a27,a28,a29,a30, $
           a31,a32,a33,a34,a35,a36,a37,a38,a39,a40,a41,a42,a43,a44,a45,a46, $
           a47,a48,a49, $
           nelems=nelems, $
           maxelems=maxelems, $
           ignorechar=ignorechar, $
           nskip=nskip, $
           single=single, $
           separator=separator, $
           nosqueeze=nosqueeze, $
           setbadval=setbadval, $
           badval=badval, $
           silent=silent

;
; reads in data from an ascii file called 'fn'
;
; e.g., readit,'somefile',jd,bmag,berr
; file can have up to 50 columns, all whitespace is ignored
; it's fine for the file to have more columns than requested
; 
; by default the columns are assumed to be numeric. to tell the
; routine that a particular column is a string define that variable
; to be any string before calling readit, e.g.
;    observer=''
;    readit,'somefile',jd,bmag,berr,observer
;
; keywords:
;
;    nelems: set this to a variable which will contain the number of 
;            elmenents output in any of the data arrays
;
;    maxelems: max number of elements to read (default: 5000)
;
;    ignorechar: ignore lines beginning with this character (in addition
;            to the defaults ';' and '#')
;
;    nskip: skip the first nskip lines in the file (default: 0)
;
;    single: data in single precision (default is double precision)
;
;    separator: character that separates the columns (default: ' ')
;
;    nosqueeze: by default, we squeeze all whitespace into one space 
;        and trim whitespace at the edges. set this to prevent that.
;        probably only want to use this if you're changing the separator
;
;    setbadval: if a numeric column has a nonnumeric entry, by default
;          we print an error message and stop. if setbadval is set
;          we just replace the bad element with badval below. note
;          that IDL considers any string that starts off numeric to
;          be numeric, so '34.3345..adf+3321' is valid = 34.3345
;
;    badval:  report nonnumeric data as this value (default: 0.0),
;          but -only- if setbadval is set
;
;    silent: don't print warning messages (still prints errors)
;

if not keyword_set(maxelems) then maxelems = 5000
if not keyword_set(nskip) then nskip = 0
single = keyword_set(single)
if not keyword_set(ignorechar) then ignorechar = ';'
if not keyword_set(separator) then separator = ' '
setbadval = keyword_set(setbadval)
if not keyword_set(badval) then badval = 0.0
silent = keyword_set(silent)

ncols = n_params() - 1   ; number of cols requested = nparams - 1 (for fn)
if ncols le 0 then begin
    message,'no data requested?! need more parameters'
endif

d = strarr(ncols,maxelems)

openr,lun,fn,/get_lun

s=''
for i=0l,nskip-1 do readf,lun,s

i = 0l
ln = nskip+1
while (not eof(lun)) and (i lt maxelems) do begin
    readf,lun,s
    if keyword_set(nosqueeze) then ss = s else ss = strtrim(strcompress(s),2)
    sl = strlen(ss)
    c = strmid(ss,0,1) 
    if (sl gt 0 and  c ne ';' and c ne '#' and c ne ignorechar) then begin
        parts = strsplit(ss,separator,/extract)
        if n_elements(parts) lt ncols then begin
            print,''
            print,'Error on line '+string(ln,format='(i0)')+' of file '+fn+':'
            print,s
            print,''
            message,'There aren''t '+ string(ncols,format='(i0)') + $
              ' columns in this line!'
        endif
        d[*,i] = parts[0:ncols-1]
        i = i+1
    endif
    ln = ln+1
endwhile

close,lun
free_lun,lun

nelems = i
if nelems ge maxelems and not silent then $
  message,'read maximum # of elements: '+fn,/info

if nelems eq 0 then begin

    if not silent then message,'no data in file: '+fn,/info
    
endif else begin

    switch ncols-1 of
        49: a49 = reform(readitconv(d[49,0:nelems-1],size(a49,/type), $
                                    single,setbadval,badval))
        48: a48 = reform(readitconv(d[48,0:nelems-1],size(a48,/type), $
                                    single,setbadval,badval))
        47: a47 = reform(readitconv(d[47,0:nelems-1],size(a47,/type), $
                                    single,setbadval,badval))
        46: a46 = reform(readitconv(d[46,0:nelems-1],size(a46,/type), $
                                    single,setbadval,badval))
        45: a45 = reform(readitconv(d[45,0:nelems-1],size(a45,/type), $
                                    single,setbadval,badval))
        44: a44 = reform(readitconv(d[44,0:nelems-1],size(a44,/type), $
                                    single,setbadval,badval))
        43: a43 = reform(readitconv(d[43,0:nelems-1],size(a43,/type), $
                                    single,setbadval,badval))
        42: a42 = reform(readitconv(d[42,0:nelems-1],size(a42,/type), $
                                    single,setbadval,badval))
        41: a41 = reform(readitconv(d[41,0:nelems-1],size(a41,/type), $
                                    single,setbadval,badval))
        40: a40 = reform(readitconv(d[40,0:nelems-1],size(a40,/type), $
                                    single,setbadval,badval))
        39: a39 = reform(readitconv(d[39,0:nelems-1],size(a39,/type), $
                                    single,setbadval,badval))
        38: a38 = reform(readitconv(d[38,0:nelems-1],size(a38,/type), $
                                    single,setbadval,badval))
        37: a37 = reform(readitconv(d[37,0:nelems-1],size(a37,/type), $
                                    single,setbadval,badval))
        36: a36 = reform(readitconv(d[36,0:nelems-1],size(a36,/type), $
                                    single,setbadval,badval))
        35: a35 = reform(readitconv(d[35,0:nelems-1],size(a35,/type), $
                                    single,setbadval,badval))
        34: a34 = reform(readitconv(d[34,0:nelems-1],size(a34,/type), $
                                    single,setbadval,badval))
        33: a33 = reform(readitconv(d[33,0:nelems-1],size(a33,/type), $
                                    single,setbadval,badval))
        32: a32 = reform(readitconv(d[32,0:nelems-1],size(a32,/type), $
                                    single,setbadval,badval))
        31: a31 = reform(readitconv(d[31,0:nelems-1],size(a31,/type), $
                                    single,setbadval,badval))
        30: a30 = reform(readitconv(d[30,0:nelems-1],size(a30,/type), $
                                    single,setbadval,badval))
        29: a29 = reform(readitconv(d[29,0:nelems-1],size(a29,/type), $
                                    single,setbadval,badval))
        28: a28 = reform(readitconv(d[28,0:nelems-1],size(a28,/type), $
                                    single,setbadval,badval))
        27: a27 = reform(readitconv(d[27,0:nelems-1],size(a27,/type), $
                                    single,setbadval,badval))
        26: a26 = reform(readitconv(d[26,0:nelems-1],size(a26,/type), $
                                    single,setbadval,badval))
        25: a25 = reform(readitconv(d[25,0:nelems-1],size(a25,/type), $
                                    single,setbadval,badval))
        24: a24 = reform(readitconv(d[24,0:nelems-1],size(a24,/type), $
                                    single,setbadval,badval))
        23: a23 = reform(readitconv(d[23,0:nelems-1],size(a23,/type), $
                                    single,setbadval,badval))
        22: a22 = reform(readitconv(d[22,0:nelems-1],size(a22,/type), $
                                    single,setbadval,badval))
        21: a21 = reform(readitconv(d[21,0:nelems-1],size(a21,/type), $
                                    single,setbadval,badval))
        20: a20 = reform(readitconv(d[20,0:nelems-1],size(a20,/type), $
                                    single,setbadval,badval))
        19: a19 = reform(readitconv(d[19,0:nelems-1],size(a19,/type), $
                                    single,setbadval,badval))
        18: a18 = reform(readitconv(d[18,0:nelems-1],size(a18,/type), $
                                    single,setbadval,badval))
        17: a17 = reform(readitconv(d[17,0:nelems-1],size(a17,/type), $
                                    single,setbadval,badval))
        16: a16 = reform(readitconv(d[16,0:nelems-1],size(a16,/type), $
                                    single,setbadval,badval))
        15: a15 = reform(readitconv(d[15,0:nelems-1],size(a15,/type), $
                                    single,setbadval,badval))
        14: a14 = reform(readitconv(d[14,0:nelems-1],size(a14,/type), $
                                    single,setbadval,badval))
        13: a13 = reform(readitconv(d[13,0:nelems-1],size(a13,/type), $
                                    single,setbadval,badval))
        12: a12 = reform(readitconv(d[12,0:nelems-1],size(a12,/type), $
                                    single,setbadval,badval))
        11: a11 = reform(readitconv(d[11,0:nelems-1],size(a11,/type), $
                                    single,setbadval,badval))
        10: a10 = reform(readitconv(d[10,0:nelems-1],size(a10,/type), $
                                    single,setbadval,badval))
        9: a09 = reform(readitconv(d[ 9,0:nelems-1],size(a09,/type), $
                                   single,setbadval,badval))
        8: a08 = reform(readitconv(d[ 8,0:nelems-1],size(a08,/type), $
                                   single,setbadval,badval))
        7: a07 = reform(readitconv(d[ 7,0:nelems-1],size(a07,/type), $
                                   single,setbadval,badval))
        6: a06 = reform(readitconv(d[ 6,0:nelems-1],size(a06,/type), $
                                   single,setbadval,badval))
        5: a05 = reform(readitconv(d[ 5,0:nelems-1],size(a05,/type), $
                                   single,setbadval,badval))
        4: a04 = reform(readitconv(d[ 4,0:nelems-1],size(a04,/type), $
                                   single,setbadval,badval))
        3: a03 = reform(readitconv(d[ 3,0:nelems-1],size(a03,/type), $
                                   single,setbadval,badval))
        2: a02 = reform(readitconv(d[ 2,0:nelems-1],size(a02,/type), $
                                   single,setbadval,badval))
        1: a01 = reform(readitconv(d[ 1,0:nelems-1],size(a01,/type), $
                                   single,setbadval,badval))
        0: a00 = reform(readitconv(d[ 0,0:nelems-1],size(a00,/type), $
                                   single,setbadval,badval))
    endswitch

endelse

end
