function readlcdata, sn, nelems=nelems, obspb=obspb, allpb=allpb $
                       , extend=extend
;
; readlcdata.pro -- reads in a light curve from a .dat file
;
; Created 2005-Nov-12
; Version 2005-Dec-06
;               
; INPUTS
;        sn: name of SN  (light curve is read from m2dir/data/{sn}.dat)
;     
; RETURN VALUE
;  array of datapoint structures with all good data
;
; OPTIONAL OUTPUTS
;    nelems: number of elements in output array
;     obspb: array of passband names corresponding to light curve good data
;     allpb: array of passband names for all the data
;
; KEYWORDS
;    extend: if set, we add elements in the structure to hold rest-frame
;            information that can be filled in later
;
; TO DO:  add option to look for an N matrix of the data itself
;

extend = keyword_set(extend)

m2dir = getenv('MLCS2K2_BASEDIR') + '/'
datadir = m2dir + 'data/'

pbs = ''
readit,datadir+sn+'.dat',pbs,jd,mag,err

allpb = pbs[uniq(pbs,sort(pbs))]


good = where(err lt 20.0 and mag lt 50.0 and jd gt -1000.0,nelems)
if nelems lt 0 then message, 'no good data!'

pbs = pbs[good]
jd = jd[good]
mag = mag[good]
err = err[good]

obspb = pbs[uniq(pbs,sort(pbs))]

lcd = {lc_datapoint,obspbname:'',jd:0d,mag:0d,err:0d}

if extend then begin
    lcde = {lc_datapoint_ext, inherits lc_datapoint $
            ,restpbname:'junk',restpbind:9999l}
    out = replicate(lcde,nelems)
endif else begin
    out = replicate(lcd,nelems)
endelse

out.obspbname = pbs
out.jd = jd
out.mag = mag
out.err = err

return, out

end
