pro readspec, fn, x, f, fits=fits, double=double
;
; fn: filename
; x:  output wavelength
; f:  output flux
;
; fits: if set, force file to be read in as fits
; double: if set force use of double precision
;
if (strpos(fn,'.fit') ne -1 or keyword_set(fits)) then begin

; FITS file

    f = readfits(fn,hdr,/silent)
    nf = sxpar(hdr,'NAXIS1') 
    w0 = sxpar(hdr,'CRVAL1')
    w1 = sxpar(hdr,'CDELT1')
    if w1 eq 0 then w1 = sxpar(hdr,'CD1_1')

    if keyword_set(double) or size(f,/type) eq 5 then begin
        f = double(f)
        x = dindgen(nf)*w1 + w0
    endif else begin
        x = findgen(nf)*w1 + w0
    endelse

endif else begin

; text file
;
;  ignore rows beginning with # or ; 
;  assume first column is wavelength, second column is flux
;  ignore everything else and lines that don't fit

    if keyword_set(double) then x=dblarr(50001) else x = fltarr(50001)
    f = x
    
    openr,b,fn,/get_lun
    s = ''
    i = 0l
    while not eof(b) do begin
        readf,b,s
        s1 = strmid(s,0,1)
        if (s1 ne ';' and s1 ne '#') then begin
            parts = strsplit(strtrim(strcompress(s),2),' ',/extract)
            if n_elements(parts) ge 2 then begin
                x[i] = float(parts[0])
                f[i] = float(parts[1])
                i = i + 1
            endif
        endif
    endwhile
    
    x = x[0:i-1]
    f = f[0:i-1]

    close,b
    free_lun,b

endelse

end
	
