pro setupfit, sn

common m2setup
common m2chisq
  
redden = getm2redden()
vectors = getm2vectors(redden.filters,info.vecname,/extend)

data = readlcdata(sn,nelems=npts,obspb=obspb,/extend)

restphase = (data.jd - startparam[0])/(1.0d + info.z)

; eliminate observations that are too early/late for our templates
okay = where(restphase ge vectors.mingoodate-10.0 and $
             restphase le vectors.maxgoodate+10.0,nokay)
if nokay lt 0 then $
  message,'no data within 10 days of template range'
data = data[okay]
restphase = restphase[okay]
npts = nokay
dpbs = data.obspbname
obspb = dpbs[uniq(dpbs,sort(dpbs))]

restpb = bestrest(obspb,info.z)

; eliminate observations that don't give useful rest-frame information
cantuse = where(restpb eq 'none',ncant,complement=canuse)
if ncant gt 0 then begin
    obsbad = obspb[cantuse]
    
    usedata = bytarr(npts)
    for i=0,npts-1 do begin
        junk = where(obsbad eq data[i].obspbname,isbad)
        usedata[i] = (isbad eq 0) ? 1 : 0
    endfor

    good = where(usedata,ngood)
    if ngood le 0 then $
      message,' no observations with acceptable rest-frame passbands'

    data = data[good]
    restphase = restphase[good]
    npts = ngood
    obspb = obspb[canuse]
    restpb = restpb[canuse]
endif

orpbind = lonarr(npts)
for i=0,npts-1 do orpbind[i] = (where(obspb eq data[i].obspbname))[0]
data.restpbname = restpb[orpbind]

for i=0,npts-1 do begin
    vind = where(vectors.filters eq data[i].restpbname,nvind)
    if nvind ne 1 then message,' invalid rest frame passband'
    data[i].restpbind = vind[0]
endfor

nuniqf = n_elements(uniq(obspb))
if n_elements(obspb) ne nuniqf then $
  message,'huh? obspb has duplicated element?'
if nuniqf eq 1 then begin
    message,'only one obs passband! you should fix A_V and R_V',/info
endif else if nuniqf eq 2 then begin
    message,'only two obs passbands! you should fix R_V',/info
endif

rfcname = defaultcolor(restpb)
kctables = preloadkc(obspb,restpb,rfcname,info)
gxtables = preloadgx(obspb,rfcname,info)

;; Make sure we have everything all set and data structures loaded
;;   by doing a test model lightcurve.  Will use the uncertainties
;;   to generate our first C matrix.
junk = getobslc(startparam,vectors,redden,info,obspb,restpb,data,orpbind $
                ,kctables=kctables,gxtables=gxtables $
                ,gxout=gx,kcout=kc,kcsig=ksig,gxsig=gsig)

s = getsmatrix(info.vecname,data.restpbname,restphase,sall,/restore)

;; Take our observational noise and added in K-correction and
;; MW-extinction correciton uncertainties
;; The extra term of 0.16*gx is from the uncertainty in the SFD98 maps
ndiag = (data.err)^2 + ksig^2 + gsig^2 + (0.16d*gx)^2
n = diag_matrix(ndiag)
for i=0,npts-1 do for j=i+1,npts-1 do n[i,j] += (0.159d)^2*gx[i]*gx[j]
for i=0,npts-1 do for j=i-1,0,-1 do n[i,j] = n[j,i]

c = s + n

; check that c is positive-definite
c = posdef(c)

cinv = invert(c,stat1)
if stat1 ne 0 then message,'matrix inversion problem: ' + string(stat1),/info

end
