pro setupgrid, sn, param, err

common m2grid

grid = readsngrid(sn)
if size(grid,/tname) ne 'STRUCT' then begin
    ; nothing in the grid file, so we use
    ; a default grid around the starting paramters
    grid = defaultgrid(param,err)
endif else if min(grid.npoints) le 0 then begin
    ; we need to autogrid some of the parameters
    defgrid = defaultgrid(param,err) 
    auto = where(grid.npoints le 0) 
    grid.npoints[auto] = defgrid.npoints[auto]
    grid.centers[auto] = defgrid.centers[auto]
    grid.steps[auto] = defgrid.steps[auto]
endif

; none of the infinitesmals should be zero
grid.steps = grid.steps > 1d-5

nt0 = grid.npoints[0]
dt0 = grid.steps[0]
t0 = grid.centers[0] + (dindgen(nt0) - nt0/2)*dt0

ndel = grid.npoints[1]
ddel = grid.steps[1]
del = grid.centers[1] + (dindgen(ndel) - ndel/2)*ddel

nrv = grid.npoints[2]
drv = grid.steps[2]
rv = grid.centers[2] + (dindgen(nrv) - nrv/2)*drv
qq = where(rv ge 0, nrv)
if nrv le 0 then message,'bad rv array!'
rv = rv[qq]

nmu0 = grid.npoints[3]
dmu0 = grid.steps[3]
mu0 = grid.centers[3] + (dindgen(nmu0) - nmu0/2)*dmu0

nav0 = grid.npoints[4]
dav0 = grid.steps[4]
av0 = grid.centers[4] + (dindgen(nav0) - nav0/2)*dav0

;
; this made sure the av grid had at most 1 negative element (which
; would get zero probability), but now that negative A_V is possible
; (depending on which prior you choose), we won't restrict the array
; 
; qq = where(av0 ge -dav0, nav0)
; if nav0 le 0 then message,'bad av0 array!'
; av0 = av0[qq]
;

finalnpoints = [nt0,ndel,nrv,nmu0,nav0]

csgrid = dblarr(nt0,ndel,nrv,nmu0,nav0) + 1d21
csgrid = reform(csgrid,nt0,ndel,nrv,nmu0,nav0)

end
